Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "     ",
 StyleBox["xPand       ",
  FontSize->36],
 "   ",
 StyleBox["application for perturbations around a General Bianchi space-time",
  
  FontSize->24]
}], "Title",
 FontSize->48],

Cell[CellGroupData[{

Cell["Set up", "Section"],

Cell[CellGroupData[{

Cell["Loading the package", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<xAct`xPand`\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Useful tools to reshape the results", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"org", "[", "expr_", "]"}], ":=", 
  RowBox[{"NoScalar", "@", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"ContractMetric", "[", "expr", "]"}], ",", 
     "$PerturbationParameter", ",", "ToCanonical"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"collect", "[", "expr_", "]"}], ":=", 
  RowBox[{"NoScalar", "@", 
   RowBox[{"Collect", "[", 
    RowBox[{"expr", ",", "$PerturbationParameter", ",", "Identity"}], 
    "]"}]}]}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Background Slicing of the manifold", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "We", " ", "must", " ", "first", " ", "define", " ", "a", " ", "manifold", 
   " ", 
   RowBox[{"(", 
    RowBox[{"with", " ", "its", " ", "indices"}], ")"}], " ", "and", " ", "a",
    " ", 
   RowBox[{"metric", ".", " ", "Incidently"}], " ", "we", " ", "choose", " ", 
   "the", " ", "dimension", " ", "of", " ", "space"}], "-", 
  RowBox[{"time", "."}]}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefManifold", "[", 
  RowBox[{"M", ",", "4", ",", 
   RowBox[{"{", 
    RowBox[{
    "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Mu]", ",", "\[Nu]", 
     ",", "\[Lambda]", ",", "\[Sigma]"}], "}"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"DefMetric", "[", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{"g", "[", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], ",", 
      RowBox[{"-", "\[Beta]"}]}], "]"}], ",", "CD", ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<;\>\"", ",", "\"\<\!\(\*OverscriptBox[\(\[Del]\), \(_\)]\)\>\""}], 
     "}"}], ",", 
    RowBox[{
    "PrintAs", "\[Rule]", "\"\<\!\(\*OverscriptBox[\(g\), \(_\)]\)\>\""}]}], 
   "]"}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ValidateSymbol", "::", "used"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Symbol \
\[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"M\\\\\\\"\\\"}]\\)\[NoBreak] is \
already used \[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"as a \
manifold\\\\\\\"\\\"}]\\)\[NoBreak].\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"DefMetric", "::", "old"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"There are already metrics \[NoBreak]\\!\\(\\*RowBox[{\\\"{\
\\\", RowBox[{\\\"g\\\", \\\",\\\", \\\"h\\\", \\\",\\\", \\\"gah2\\\"}], \
\\\"}\\\"}]\\)\[NoBreak] in vbundle \
\[NoBreak]\\!\\(\\*InterpretationBox[StyleBox[\\\"\[DoubleStruckCapitalT]M\\\"\
, Rule[AutoSpacing, False], Rule[ShowAutoStyles, False]], TangentM, \
Rule[Editable, False]]\\)\[NoBreak].\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ValidateSymbol", "::", "used"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Symbol \
\[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"g\\\\\\\"\\\"}]\\)\[NoBreak] is \
already used \[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"as a metric\\\\\\\"\\\"}]\
\\)\[NoBreak].\"\>"}]], "Message", "MSG"]
}, Open  ]],

Cell["\<\
We have a general function ' SetSlicing' which defines many properties for \
the splitting.
From ambient metric g, then the vector normal to hyper surfaces u, and the \
induced metric h are defined.
Then many relations that are to be deduced from this 1 + (n - 1) splitting \
are implemented.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "$ListOfSpaceTypes"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"Possible space types are: Anisotropic, BianchiB, BianchiA, \
BianchiI, FLCurved, FLFlat and Minkowski.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info763761239827-1327514"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetSlicing", "[", 
   RowBox[{"g", ",", "n", ",", "h", ",", "cd", ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<|\>\"", ",", "\"\<\!\(\*OverscriptBox[\(D\), \(_\)]\)\>\""}], "}"}],
     ",", "\"\<BianchiB\>\""}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PrintAs", "[", "Kh", "]"}], "^=", "\"\<\[Sigma]\>\""}], 
  ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ValidateSymbol", "::", "used"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Symbol \
\[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"h\\\\\\\"\\\"}]\\)\[NoBreak] is \
already used \[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"as a metric\\\\\\\"\\\"}]\
\\)\[NoBreak].\"\>"}]], "Message", "MSG"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
     "8"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "h", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4, 5, 6, 7, 8}], 
   " have been declared as UpValues for ", $CellContext`h, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
     "8"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "h", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4, 5, 6, 7, 8}], 
   " have been declared as UpValues for ", $CellContext`h, "."],
  Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Unset", "::", "norep"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Assignment on \[NoBreak]\\!\\(\\*RowBox[{\\\"cd\\\"}]\\)\
\[NoBreak] for \
\[NoBreak]\\!\\(\\*InterpretationBox[StyleBox[RowBox[{SuperscriptBox[\\\"\\\\!\
\\\\(\\\\*OverscriptBox[\\\\(D\\\\), \\\\(_\\\\)]\\\\)\\\", \\\"\\\\!\\\\(a\\\
\\+_\\\\)\\\"], StyleBox[\\\"(\\\", Rule[FontColor, RGBColor[1, 0, 0]]], \
\\\"xAct`xPand`Private`expr_\\\", StyleBox[\\\")\\\", Rule[FontColor, \
RGBColor[1, 0, 0]]]}], Rule[AutoSpacing, False], Rule[ShowAutoStyles, \
False]], cd[Pattern[a, Blank[]]][Scalar[Pattern[xAct`xPand`Private`expr, \
Blank[]]]], Rule[Editable, False]]\\)\[NoBreak] not found. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/Unset/norep\\\", \
ButtonNote -> \\\"Unset::norep\\\"]\\)\"\>"}]], "Message", "MSG"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "n", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2}], " have been declared as UpValues for ", $CellContext`n, 
   "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "n", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4}], 
   " have been declared as UpValues for ", $CellContext`n, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
     "8"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "n", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2, 3, 4, 5, 6, 7, 8}], 
   " have been declared as UpValues for ", $CellContext`n, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "\[ScriptCapitalN]0h", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`\
\[ScriptCapitalN]0h, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Warning: Tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptCapitalN]ih", 
   "\[InvisibleSpace]", "\<\"is already defined. It cannot be redefined \
without undefining it. **\"\>"}],
  SequenceForm[
  "** Warning: Tensor ", $CellContext`\[ScriptCapitalN]ih, 
   "is already defined. It cannot be redefined without undefining it. **"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Warning: Tensor \"\>", "\[InvisibleSpace]", 
   "\[ScriptCapitalN]h", 
   "\[InvisibleSpace]", "\<\"is already defined. It cannot be redefined \
without undefining it. **\"\>"}],
  SequenceForm[
  "** Warning: Tensor ", $CellContext`\[ScriptCapitalN]h, 
   "is already defined. It cannot be redefined without undefining it. **"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "ah", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`ah, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Hh", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Hh, "."],
  Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"MakeRule", "::", "terms"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"There is more than one term on the LHS of rule.\"\>"}]], \
"Message", "MSG"]
}, Open  ]],

Cell["\<\
We define the metric and velocity perturbations (plus many fields which are \
going to be used in the splitting of these perturbations)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefMetricFields", "[", 
  RowBox[{"g", ",", "dg", ",", "h"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefMatterFields", "[", 
  RowBox[{"u", ",", "du", ",", "h"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"** Warning: Metric perturbation already defined. This \
cannot be redefined without undefining it. **\"\>"], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "\[Phi]h", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`\[Phi]h, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Bsh", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Bsh, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Bvh", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Bvh, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "\[Psi]h", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`\[Psi]h, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Esh", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Esh, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Evh", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Evh, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Eth", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Eth, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Th", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Th, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Lsh", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Lsh, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Lvh", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Lvh, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "\[CurlyPhi]", "\[InvisibleSpace]", "\<\".\"\>"}],
  
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", xAct`xPand`\[CurlyPhi], "."],
  
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "\[Rho]u", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`\[Rho]u, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Pu", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Pu, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Vspathu", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Vspathu, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "V0hu", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`V0hu, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Vshu", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Vshu, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefProjectedTensor: The projection properties on the \
hypersurfaces associated with the induced metric \"\>", "\[InvisibleSpace]", 
   "h", "\[InvisibleSpace]", "\<\" have already been defined for the tensor \
\"\>", "\[InvisibleSpace]", "Vvhu", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "** DefProjectedTensor: The projection properties on the hypersurfaces \
associated with the induced metric ", $CellContext`h, 
   " have already been defined for the tensor ", $CellContext`Vvhu, "."],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Warning: Tensor \"\>", "\[InvisibleSpace]", "u", 
   "\[InvisibleSpace]", "\<\"is already defined. It cannot be redefined \
without undefining it. **\"\>"}],
  SequenceForm[
  "** Warning: Tensor ", $CellContext`u, 
   "is already defined. It cannot be redefined without undefining it. **"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** Warning: Tensor \"\>", "\[InvisibleSpace]", "du", 
   "\[InvisibleSpace]", "\<\"is already defined. It cannot be redefined \
without undefining it. **\"\>"}],
  SequenceForm[
  "** Warning: Tensor ", $CellContext`du, 
   "is already defined. It cannot be redefined without undefining it. **"],
  Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conformal transformation", "Subsection"],

Cell["\<\
When evaluating SetSlicing, a conformal metric has been defined by calling \
the function DefConformalMetric[g,Sh].  We can check indeed it is in the list \
of metrics\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData["$Metrics"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"g", ",", "h", ",", "gah2"}], "}"}]], "Output"]
}, Open  ]],

Cell["That is there is a new metric gah2 whith relations", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ConformalRules", "[", 
  RowBox[{
   RowBox[{"First", "@", "$Metrics"}], ",", "gah2"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Conformal", "[", 
   RowBox[{"g", ",", "gah2"}], "]"}], "[", 
  RowBox[{"g", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Conformal", "[", 
   RowBox[{"g", ",", "gah2"}], "]"}], "[", 
  RowBox[{"g", "[", 
   RowBox[{
    RowBox[{"-", "\[Mu]"}], ",", 
    RowBox[{"-", "\[Nu]"}]}], "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {
             UnderscriptBox[
              UnderscriptBox["\[Alpha]", "_"], "_"], 
             UnderscriptBox[
              UnderscriptBox["\[Beta]", "_"], "_"]},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[
      PatternTest[
       Pattern[$CellContext`\[Alpha], 
        Blank[]], xAct`xTensor`DownIndexQ], 
      PatternTest[
       Pattern[$CellContext`\[Beta], 
        Blank[]], xAct`xTensor`DownIndexQ]],
     Editable->False], "\[Rule]", 
    FractionBox[
     InterpretationBox[
      StyleBox[GridBox[{
         {
          RowBox[{"[", 
           RowBox[{
            OverscriptBox["g", "_"], 
            SuperscriptBox["a", "2"]}], "]"}], 
          StyleBox[GridBox[{
             {"\[Alpha]", "\[Beta]"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`gah2[$CellContext`\[Alpha], $CellContext`\[Beta]],
      Editable->False], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {
             UnderscriptBox[
              UnderscriptBox["\[Alpha]", "_"], "_"], 
             UnderscriptBox[
              UnderscriptBox["\[Beta]", "_"], "_"]},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[
      PatternTest[
       Pattern[$CellContext`\[Alpha], 
        Blank[]], xAct`xTensor`UpIndexQ], 
      PatternTest[
       Pattern[$CellContext`\[Beta], 
        Blank[]], xAct`xTensor`UpIndexQ]],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {
          RowBox[{"i", "[", 
           RowBox[{
            OverscriptBox["g", "_"], 
            SuperscriptBox["a", "2"]}], "]"}], 
          StyleBox[GridBox[{
             {"\[Alpha]", "\[Beta]"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Invgah2[$CellContext`\[Alpha], $CellContext`\[Beta]],
      Editable->False]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       OverscriptBox["g", "_"], 
       OverscriptBox[
        StyleBox["~",
         FontColor->RGBColor[0, 0, 0]], 
        StyleBox["~",
         FontColor->RGBColor[0, 0, 0]]]],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Detg[],
     Editable->False], "\[Rule]", 
    FractionBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        RowBox[{"[", 
         RowBox[{
          OverscriptBox["g", "_"], 
          SuperscriptBox["a", "2"]}], "]"}], 
        OverscriptBox[
         StyleBox["~",
          FontColor->RGBColor[0, 0, 0]], 
         StyleBox["~",
          FontColor->RGBColor[0, 0, 0]]]],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Detgah2[],
      Editable->False], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "8"]]}]}], "}"}]], "Output"],

Cell[BoxData[
 FractionBox[
  InterpretationBox[
   StyleBox[GridBox[{
      {
       OverscriptBox["g", "_"], 
       StyleBox[GridBox[{
          {"\[Mu]", "\[Nu]"},
          {" ", " "}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`g[$CellContext`\[Mu], $CellContext`\[Nu]],
   Editable->False], 
  SuperscriptBox[
   InterpretationBox[
    StyleBox[
     RowBox[{
      StyleBox["(",
       FontColor->RGBColor[1, 0, 0]], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], 
      StyleBox[")",
       FontColor->RGBColor[1, 0, 0]]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xTensor`Scalar[
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]],
    Editable->False], "2"]]], "Output"],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {
       OverscriptBox["g", "_"], 
       StyleBox[GridBox[{
          {" ", " "},
          {"\[Mu]", "\[Nu]"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
   Editable->False], " ", 
  SuperscriptBox[
   InterpretationBox[
    StyleBox[
     RowBox[{
      StyleBox["(",
       FontColor->RGBColor[1, 0, 0]], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], 
      StyleBox[")",
       FontColor->RGBColor[1, 0, 0]]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xTensor`Scalar[
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]],
    Editable->False], "2"]}]], "Output"]
}, Open  ]],

Cell["\<\
We have then a function Conformal which enables to perform conformal \
transformations, and to express the result in terms of the original metric\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"Te", "[", 
    RowBox[{"-", "\[Alpha]"}], "]"}], ",", 
   RowBox[{"{", "M", "}"}], ",", 
   RowBox[{"PrintAs", "\[Rule]", "\"\<T\>\""}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Te", "[", 
    RowBox[{"-", "\[Alpha]"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Te[-$CellContext`\[Alpha]], ". ", ""],
  Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Conformal", "[", 
   RowBox[{"g", ",", "gah2"}], "]"}], "[", 
  RowBox[{
   RowBox[{"CD", "[", 
    RowBox[{"-", "\[Nu]"}], "]"}], "[", 
   RowBox[{"Te", "[", 
    RowBox[{"-", "\[Mu]"}], "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Conformal", "[", 
   RowBox[{"g", ",", "gah2"}], "]"}], "[", 
  RowBox[{"ChristoffelCD", "[", 
   RowBox[{"\[Alpha]", ",", 
    RowBox[{"-", "\[Nu]"}], ",", 
    RowBox[{"-", "\[Beta]"}]}], "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["g", "_"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {"\[Alpha]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Te[$CellContext`\[Alpha]],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`\[Alpha]][
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]],
     Editable->False], ")"}]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"T", 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Te[-$CellContext`\[Nu]],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Del]", "_"], "\[Mu]"], 
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`\[Mu]][
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Del]", "_"], "\[Nu]"], GridBox[{
         {"T", 
          StyleBox[GridBox[{
             {" "},
             {"\[Mu]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`\[Nu]][
      $CellContext`Te[-$CellContext`\[Mu]]],
     Editable->False], ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {
       RowBox[{"\[CapitalGamma]", "[", 
        OverscriptBox["\[Del]", "_"], "]"}], 
       StyleBox[GridBox[{
          {"\[Alpha]", " ", " "},
          {" ", "\[Beta]", "\[Nu]"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`ChristoffelCD[$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Nu]],
   Editable->False], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Beta]", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`\[Alpha]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     RowBox[{
      StyleBox["(",
       FontColor->RGBColor[1, 0, 0]], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], 
      StyleBox[")",
       FontColor->RGBColor[1, 0, 0]]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xTensor`Scalar[
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Beta]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Beta]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     RowBox[{
      StyleBox["(",
       FontColor->RGBColor[1, 0, 0]], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], 
      StyleBox[")",
       FontColor->RGBColor[1, 0, 0]]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xTensor`Scalar[
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]],
    Editable->False]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Nu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Nu]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     RowBox[{
      StyleBox["(",
       FontColor->RGBColor[1, 0, 0]], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], 
      StyleBox[")",
       FontColor->RGBColor[1, 0, 0]]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xTensor`Scalar[
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]],
    Editable->False]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Conformal", "[", 
   RowBox[{"g", ",", "gah2"}], "]"}], "[", 
  RowBox[{"RicciScalarCD", "[", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"AA", "=", 
  RowBox[{
   RowBox[{"ExpandPerturbation", "@", 
    RowBox[{"Perturbed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Conformal", "[", 
        RowBox[{"g", ",", "gah2"}], "]"}], "[", 
       RowBox[{"RicciCD", "[", 
        RowBox[{
         RowBox[{"-", "\[Mu]"}], ",", 
         RowBox[{"-", "\[Nu]"}]}], "]"}], "]"}], ",", "1"}], "]"}]}], "//", 
   "org"}]}], "\[IndentingNewLine]", 
 RowBox[{"BB", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Conformal", "[", 
     RowBox[{"g", ",", "gah2"}], "]"}], "[", 
    RowBox[{"ExpandPerturbation", "@", 
     RowBox[{"Perturbed", "[", 
      RowBox[{
       RowBox[{"RicciCD", "[", 
        RowBox[{
         RowBox[{"-", "\[Mu]"}], ",", 
         RowBox[{"-", "\[Nu]"}]}], "]"}], ",", "1"}], "]"}]}], "]"}], "//", 
   "org"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   InterpretationBox[
    StyleBox[
     RowBox[{"R", "[", 
      OverscriptBox["\[Del]", "_"], "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciScalarCD[],
    Editable->False], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      RowBox[{
       StyleBox["(",
        FontColor->RGBColor[1, 0, 0]], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], 
       StyleBox[")",
        FontColor->RGBColor[1, 0, 0]]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`CD[$CellContext`\[Alpha]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      RowBox[{
       StyleBox["(",
        FontColor->RGBColor[1, 0, 0]], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], 
       StyleBox[")",
        FontColor->RGBColor[1, 0, 0]]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]],
     Editable->False], "3"]]}]], "Output"],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {
       RowBox[{"R", "[", 
        OverscriptBox["\[Del]", "_"], "]"}], 
       StyleBox[GridBox[{
          {" ", " "},
          {"\[Mu]", "\[Nu]"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`RicciCD[-$CellContext`\[Mu], -$CellContext`\[Nu]],
   Editable->False], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`CD[$CellContext`\[Alpha]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`\[Alpha]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Mu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Mu]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Nu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Nu]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Nu]"], 
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Mu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Nu]][
       $CellContext`CD[-$CellContext`\[Mu]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", " "},
                {" ", "\[Mu]", "\[Nu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`dg[
          xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
            SuperscriptBox[
             OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`\[Alpha]][
           $CellContext`CD[$CellContext`\[Alpha]][
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]]]],
          Editable->False], ")"}]}], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SuperscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", " "},
                {" ", "\[Mu]", "\[Nu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", "\[Alpha]"},
                {" ", "\[Nu]", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Nu], $CellContext`\[Alpha]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Nu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", "\[Alpha]"},
                {" ", "\[Mu]", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[-$CellContext`\[Nu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], $CellContext`\[Alpha]]]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", " ", " "},
               {" ", "\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", "\[Beta]", " "},
                 {" ", " ", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], $CellContext`\[Beta], -$CellContext`\[Beta]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", "\[Beta]"},
                 {" ", "\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Beta]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Alpha], $CellContext`\[Beta]]],
         
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", "\[Alpha]", "\[Beta]"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Beta]][
          $CellContext`CD[-$CellContext`\[Alpha]][
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", " ", " "},
               {" ", "\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Beta]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Nu], -$CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Nu]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Nu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Nu]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", "\[Alpha]", " "},
                {" ", " ", "\[Alpha]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Nu]][
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[
           1], $CellContext`\[Alpha], -$CellContext`\[Alpha]]]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {
       RowBox[{"R", "[", 
        OverscriptBox["\[Del]", "_"], "]"}], 
       StyleBox[GridBox[{
          {" ", " "},
          {"\[Mu]", "\[Nu]"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`RicciCD[-$CellContext`\[Mu], -$CellContext`\[Nu]],
   Editable->False], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`CD[$CellContext`\[Alpha]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`\[Alpha]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Mu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Mu]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Nu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Nu]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Nu]"], 
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Mu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Nu]][
       $CellContext`CD[-$CellContext`\[Mu]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", " "},
                {" ", "\[Mu]", "\[Nu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`dg[
          xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
            SuperscriptBox[
             OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`\[Alpha]][
           $CellContext`CD[$CellContext`\[Alpha]][
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]]]],
          Editable->False], ")"}]}], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SuperscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", " "},
                {" ", "\[Mu]", "\[Nu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", "\[Alpha]"},
                {" ", "\[Nu]", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Nu], $CellContext`\[Alpha]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Nu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", "\[Alpha]"},
                {" ", "\[Mu]", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[-$CellContext`\[Nu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], $CellContext`\[Alpha]]]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", " ", " "},
               {" ", "\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", "\[Beta]", " "},
                 {" ", " ", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], $CellContext`\[Beta], -$CellContext`\[Beta]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", "\[Beta]"},
                 {" ", "\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Beta]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Alpha], $CellContext`\[Beta]]],
         
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", "\[Alpha]", "\[Beta]"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Beta]][
          $CellContext`CD[-$CellContext`\[Alpha]][
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", " ", " "},
               {" ", "\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Beta]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Nu], -$CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Nu]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Nu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Nu]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", "\[Alpha]", " "},
                {" ", " ", "\[Alpha]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Nu]][
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[
           1], $CellContext`\[Alpha], -$CellContext`\[Alpha]]]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AA", "-", "BB"}], "//", "org"}]], "Input"],

Cell[BoxData["0"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Projected tensors", "Subsection"],

Cell["DefMetricPerturbations has defined many tensors", "Text"],

Cell[CellGroupData[{

Cell[BoxData["$Tensors"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "g", ",", "epsilong", ",", "Tetrag", ",", "Tetrag\[Dagger]", ",", 
   "TorsionCD", ",", "ChristoffelCD", ",", "RiemannCD", ",", "RicciCD", ",", 
   "RicciScalarCD", ",", "EinsteinCD", ",", "WeylCD", ",", "TFRicciCD", ",", 
   "KretschmannCD", ",", "Detg", ",", "n", ",", "h", ",", "epsilonh", ",", 
   "Tetrah", ",", "Tetrah\[Dagger]", ",", "Torsioncd", ",", "Christoffelcd", 
   ",", "Riemanncd", ",", "Riccicd", ",", "RicciScalarcd", ",", "Einsteincd", 
   ",", "Weylcd", ",", "TFRiccicd", ",", "Kretschmanncd", ",", "Deth", ",", 
   "ExtrinsicKh", ",", "Accelerationn", ",", "\[ScriptCapitalN]0h", ",", 
   "\[ScriptCapitalN]ih", ",", "\[ScriptCapitalN]h", ",", 
   "d\[ScriptCapitalN]h", ",", "ah", ",", "Hh", ",", "gah2", ",", "Invgah2", 
   ",", "epsilongah2", ",", "Tetragah2", ",", "Tetragah2\[Dagger]", ",", 
   "TorsionCDah2", ",", "ChristoffelCDah2", ",", "RiemannDownCDah2", ",", 
   "RiemannCDah2", ",", "RicciCDah2", ",", "RicciScalarCDah2", ",", 
   "EinsteinCDah2", ",", "WeylCDah2", ",", "TFRicciCDah2", ",", 
   "KretschmannCDah2", ",", "Detgah2", ",", "Connectionh", ",", "CSh", ",", 
   "nth", ",", "avh", ",", "Kh", ",", "dg", ",", "\[Phi]h", ",", "Bsh", ",", 
   "Bvh", ",", "\[Psi]h", ",", "Esh", ",", "Evh", ",", "Eth", ",", "Th", ",", 
   "Lsh", ",", "Lvh", ",", "\[CurlyPhi]", ",", "\[Rho]u", ",", "Pu", ",", 
   "Vspathu", ",", "V0hu", ",", "Vshu", ",", "Vvhu", ",", "u", ",", "du", ",",
    "ChristoffelCDCDah2", ",", "W", ",", "Te"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
We can see that the first label index in these tensors is the order of \
perturbations, and the second one is the number of \"time derivative\"\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Eth", "[", 
  RowBox[{
   RowBox[{"LI", "[", "1", "]"}], ",", 
   RowBox[{"LI", "[", "1", "]"}], ",", 
   RowBox[{"-", "\[Mu]"}], ",", 
   RowBox[{"-", "\[Nu]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LieD", "[", 
   RowBox[{"n", "[", "\[Alpha]", "]"}], "]"}], "@", 
  "%"}], "\[IndentingNewLine]", 
 RowBox[{"PerturbationOrder", "[", "%%", "]"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   RowBox[{
    OverscriptBox["\[Null]", 
     StyleBox[
      RowBox[{"(", "1", ")"}],
      FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
    OverscriptBox[
     InterpretationBox[
      StyleBox[GridBox[{
         {"E", 
          StyleBox[GridBox[{
             {" ", " "},
             {"\[Mu]", "\[Nu]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
      Editable->False], "\[Prime]"]}],
   ShowAutoStyles->False,
   AutoSpacing->False],
  $CellContext`Eth[
   xAct`xTensor`LI[1], 
   xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
  Editable->False]], "Output"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   RowBox[{
    OverscriptBox["\[Null]", 
     StyleBox[
      RowBox[{"(", "1", ")"}],
      FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
    OverscriptBox[
     InterpretationBox[
      StyleBox[GridBox[{
         {"E", 
          StyleBox[GridBox[{
             {" ", " "},
             {"\[Mu]", "\[Nu]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
      Editable->False], "\[Prime]\[Prime]"]}],
   ShowAutoStyles->False,
   AutoSpacing->False],
  $CellContext`Eth[
   xAct`xTensor`LI[1], 
   xAct`xTensor`LI[2], -$CellContext`\[Mu], -$CellContext`\[Nu]],
  Editable->False]], "Output"],

Cell[BoxData["1"], "Output"]
}, Open  ]],

Cell[TextData[{
 "For any tensor, the prime notation, means: ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["T", "\[Mu]\[Nu]"], "'"], TraditionalForm]],
  FontSize->14,
  FontColor->RGBColor[1, 0, 1]],
 StyleBox[" = ",
  FontSize->14,
  FontColor->RGBColor[1, 0, 1]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalL]", "n"], 
    SubscriptBox["T", "\[Mu]\[Nu]"]}], TraditionalForm]],
  FontSize->14,
  FontColor->RGBColor[1, 0, 1]],
 ",  which implies for the contravariant indices: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["T", "\[Mu]\[Nu]"], "'"}], "=", 
    RowBox[{
     SuperscriptBox["g", "\[Alpha]\[Mu]"], 
     SuperscriptBox["g", "\[Beta]\[Nu]"], " ", 
     SubscriptBox["\[ScriptCapitalL]", "n"], " ", 
     RowBox[{
      SubscriptBox["T", "\[Alpha]\[Beta]"], " ", "."}]}]}], TraditionalForm]]],
 "\nIn case the indices are in upper position, we do not use this \
\[OpenCurlyQuote]prime\[CloseCurlyQuote] notation to avoid confusion (see \
examples below).\nThis stems from the fact that, for Bianchi space-times, we \
have: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", "n"], 
     SuperscriptBox["g", "\[Mu]\[Nu]"]}], "=", 
    RowBox[{"2", 
     SubscriptBox["\[Sigma]", "\[Mu]\[Nu]"]}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", "n"], 
     SuperscriptBox["g", "\[Mu]\[Nu]"]}], "=", 
    RowBox[{
     RowBox[{"-", "2"}], 
     SuperscriptBox["\[Sigma]", "\[Mu]\[Nu]"]}]}], TraditionalForm]]],
 ".\n\n(for Friedmann-Lemaitre cosmologies, this detail does not matter since \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", "n"], 
     SubscriptBox["g", "\[Mu]\[Nu]"]}], " ", "=", " ", "0", " "}], 
   TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalL]", "n"], 
    SuperscriptBox["g", "\[Mu]\[Nu]"]}], TraditionalForm]]],
 " = 0)."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eth", "[", 
  RowBox[{
   RowBox[{"LI", "[", "1", "]"}], ",", 
   RowBox[{"LI", "[", "1", "]"}], ",", "\[Mu]", ",", "\[Nu]"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"xPand", "::", "makeboxes"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"For anisotropic manifolds, the second label-index can be \
only interpreted as a Lie derivative for indices down.\"\>"}]], "Message", \
"MSG"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   RowBox[{
    OverscriptBox["\[Null]", 
     RowBox[{"(", "1", ")"}]], "\[NegativeThinSpace]", 
    OverscriptBox[
     InterpretationBox[
      StyleBox[GridBox[{
         {"E", 
          StyleBox[GridBox[{
             {"\[Mu]", "\[Nu]"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[$CellContext`\[Mu], $CellContext`\[Nu]],
      Editable->False], "1"]}],
   ShowAutoStyles->False,
   AutoSpacing->False],
  $CellContext`Eth[
   xAct`xTensor`LI[1], 
   xAct`xTensor`LI[1], $CellContext`\[Mu], $CellContext`\[Nu]],
  Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["General splitting of perturbations", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"order", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$FirstOrderVectorPerturbations", "=", "True"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$FirstOrderTensorPerturbations", "=", "True"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell["Curvature fields", "Subsection"],

Cell["\<\
We will first review all the steps which are necessary in order to compute \
cosmological perturbations.
  We will then see that some functions are predefined to perform all these \
steps at once\
\>", "Text"],

Cell["\<\
First the perturbations in general are obtained by first performing a \
conformal transformation, and then perturbing the result with the tools of \
xPert (Perturbed[..., order])
For instance the Ricci scalar can be conformally transformed, and then \
perturbed. We decompose these steps to see clearly what happens.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"RicciScalarCD", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Conformal", "[", 
   RowBox[{"g", ",", "gah2"}], "]"}], "[", "%", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"MyR", "=", 
  RowBox[{
   RowBox[{"ExpandPerturbation", "@", 
    RowBox[{"Perturbed", "[", 
     RowBox[{"%", ",", "1"}], "]"}]}], "//", "org"}]}], "\[IndentingNewLine]", 
 RowBox[{"MyRicci", "=", 
  RowBox[{
   RowBox[{"ExpandPerturbation", "@", 
    RowBox[{"Perturbed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Conformal", "[", 
        RowBox[{"g", ",", "gah2"}], "]"}], "[", 
       RowBox[{"RicciCD", "[", 
        RowBox[{
         RowBox[{"-", "\[Mu]"}], ",", 
         RowBox[{"-", "\[Nu]"}]}], "]"}], "]"}], ",", "1"}], "]"}]}], "//", 
   "org"}]}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  StyleBox[
   RowBox[{"R", "[", 
    OverscriptBox["\[Del]", "_"], "]"}],
   ShowAutoStyles->False,
   AutoSpacing->False],
  $CellContext`RicciScalarCD[],
  Editable->False]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   InterpretationBox[
    StyleBox[
     RowBox[{"R", "[", 
      OverscriptBox["\[Del]", "_"], "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciScalarCD[],
    Editable->False], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      RowBox[{
       StyleBox["(",
        FontColor->RGBColor[1, 0, 0]], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], 
       StyleBox[")",
        FontColor->RGBColor[1, 0, 0]]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`CD[$CellContext`\[Alpha]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      RowBox[{
       StyleBox["(",
        FontColor->RGBColor[1, 0, 0]], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], 
       StyleBox[")",
        FontColor->RGBColor[1, 0, 0]]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]],
     Editable->False], "3"]]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   InterpretationBox[
    StyleBox[
     RowBox[{"R", "[", 
      OverscriptBox["\[Del]", "_"], "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciScalarCD[],
    Editable->False], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`CD[$CellContext`\[Alpha]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "3"]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", "\[Alpha]", "\[Beta]"},
                {" ", " ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`dg[
          xAct`xTensor`LI[1], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], " ", 
        InterpretationBox[
         StyleBox[GridBox[{
            {
             RowBox[{"R", "[", 
              OverscriptBox["\[Del]", "_"], "]"}], 
             StyleBox[GridBox[{
                {" ", " "},
                {"\[Alpha]", "\[Beta]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`RicciCD[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
         Editable->False]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]]}], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", "\[Beta]", " "},
                 {" ", " ", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], $CellContext`\[Beta], -$CellContext`\[Beta]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", "\[Beta]"},
                 {" ", "\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Beta]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Alpha], $CellContext`\[Beta]]],
         
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", "\[Alpha]", "\[Beta]"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Beta]][
          $CellContext`CD[-$CellContext`\[Alpha]][
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"]], "+", 
     FractionBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["\[Del]", "_"], "\[Beta]"], 
         SubscriptBox[
          OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", "\[Alpha]", "\[Beta]"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`\[Beta]][
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`dg[
          xAct`xTensor`LI[1], $CellContext`\[Alpha], $CellContext`\[Beta]]]],
       Editable->False], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["\[Del]", "_"], "\[Beta]"], 
         SuperscriptBox[
          OverscriptBox["\[Del]", "_"], "\[Beta]"], GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", "\[Alpha]", " "},
               {" ", " ", "\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`\[Beta]][
        $CellContext`CD[$CellContext`\[Beta]][
         $CellContext`dg[
          xAct`xTensor`LI[1], $CellContext`\[Alpha], -$CellContext`\[Alpha]]]],
       Editable->False], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]]}], ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {
       RowBox[{"R", "[", 
        OverscriptBox["\[Del]", "_"], "]"}], 
       StyleBox[GridBox[{
          {" ", " "},
          {"\[Mu]", "\[Nu]"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`RicciCD[-$CellContext`\[Mu], -$CellContext`\[Nu]],
   Editable->False], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`CD[$CellContext`\[Alpha]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[$CellContext`\[Alpha]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"4", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Mu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Mu]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Nu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Nu]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Nu]"], 
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Mu]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Nu]][
       $CellContext`CD[-$CellContext`\[Mu]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]]],
      Editable->False], ")"}]}], 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", " "},
                {" ", "\[Mu]", "\[Nu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`dg[
          xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            SubscriptBox[
             OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
            SuperscriptBox[
             OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`CD[-$CellContext`\[Alpha]][
           $CellContext`CD[$CellContext`\[Alpha]][
            $CellContext`ah[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[0]]]],
          Editable->False], ")"}]}], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SuperscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", " "},
                {" ", "\[Mu]", "\[Nu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", "\[Alpha]"},
                {" ", "\[Nu]", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Nu], $CellContext`\[Alpha]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Nu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", " ", "\[Alpha]"},
                {" ", "\[Mu]", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Alpha]][
         $CellContext`CD[-$CellContext`\[Nu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], $CellContext`\[Alpha]]]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", " ", " "},
               {" ", "\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", "\[Beta]", " "},
                 {" ", " ", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], $CellContext`\[Beta], -$CellContext`\[Beta]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Alpha]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", "\[Beta]"},
                 {" ", "\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Beta]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Alpha], $CellContext`\[Beta]]],
         
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", "\[Alpha]", "\[Beta]"},
               {" ", " ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Beta]][
          $CellContext`CD[-$CellContext`\[Alpha]][
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Delta]g", 
            StyleBox[GridBox[{
               {"1", " ", " "},
               {" ", "\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`dg[
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["g", "_"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Beta]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Beta]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Nu], -$CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
           OverscriptBox[
            InterpretationBox[
             StyleBox["a",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`ah[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[$CellContext`\[Alpha]][
          $CellContext`ah[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["\[Del]", "_"], "\[Nu]"], GridBox[{
             {"\[Delta]g", 
              StyleBox[GridBox[{
                 {"1", " ", " "},
                 {" ", "\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`CD[-$CellContext`\[Nu]][
          $CellContext`dg[
           xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Nu]"], 
          SubscriptBox[
           OverscriptBox["\[Del]", "_"], "\[Mu]"], GridBox[{
            {"\[Delta]g", 
             StyleBox[GridBox[{
                {"1", "\[Alpha]", " "},
                {" ", " ", "\[Alpha]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`CD[-$CellContext`\[Nu]][
         $CellContext`CD[-$CellContext`\[Mu]][
          $CellContext`dg[
           xAct`xTensor`LI[
           1], $CellContext`\[Alpha], -$CellContext`\[Alpha]]]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
We need some rules to replace the metric perturbations, and to parameterize \
its background 3+1 splitting. SplitMetric builds this rules for a given \
splitting and a given gauge.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VisualizeTensor", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"dg", "[", 
     RowBox[{
      RowBox[{"LI", "[", "1", "]"}], ",", "\[Mu]", ",", "\[Nu]"}], "]"}], "/.", 
    RowBox[{"SplitMetric", "[", 
     RowBox[{"g", ",", "dg", ",", "h", ",", "\"\<NewtonGauge\>\""}], "]"}]}], 
   ",", "h"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"", "n", "h"},
    {"n", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], 
     RowBox[{"-", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Nu]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Nu]],
        Editable->False], ")"}]}]},
    {"h", 
     RowBox[{"-", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Mu]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Mu]],
        Editable->False], ")"}]}], 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Mu]", "\[Nu]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Mu], $CellContext`\[Nu]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Mu], $CellContext`\[Nu]],
         Editable->False], ")"}]}], "-", 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {"\[Mu]", "\[Nu]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[$CellContext`\[Mu], $CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"\[Sigma]", 
                StyleBox[GridBox[{
                   {"\[Mu]", "\[Nu]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Kh[$CellContext`\[Mu], $CellContext`\[Nu]],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Kh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0], $CellContext`\[Mu], $CellContext`\[Nu]],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]]}]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output"]
}, Open  ]],

Cell["\<\
Then we use the function SplitPerturbations which takes as arguments a \
perturbed expression, a list of delayed rules, and the splitting details \
{h,u,g}. The delayed rules are usually built through the function SplitMetric.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplitPerturbations", "[", 
  RowBox[{"MyR", ",", 
   RowBox[{"SplitMetric", "[", 
    RowBox[{"g", ",", "dg", ",", "h", ",", "\"\<NewtonGauge\>\""}], "]"}], 
   ",", "h"}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      RowBox[{"R", "[", 
       OverscriptBox["\[Del]", "_"], "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "8.376772`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]^(-2) $CellContext`RicciScalarCD[], 
   " +... was performed in ", 8.376772, " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {" "},
             {"\[Alpha]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[-$CellContext`\[Alpha]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {"\[Alpha]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[$CellContext`\[Alpha]],
      Editable->False]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]]}], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Alpha]", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Alpha]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Beta]", "\[Gamma]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Beta], $CellContext`\[Gamma]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[-$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Beta]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Bvh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
We can perform all these steps in one piece. The main three steps are:

1) Conformal transformation with Conformal, 
2) Perturbation with Expandperturbation@Perturbed, 
3) The creation of a rule for the metric perturbation and the matter \
perturbations for a given gauge choice. This is done through SplitMetric and \
SplitMatter
4) The splitting of the result by SplitPerturbations 

The function ToxPand is designed to perform these three steps at once (that\
\[CloseCurlyQuote]s the function for users who do not want to build by \
themselves the rules to split the perturbations.)
We use it to create a function which does everything for our choice of gauge \
and our splitting (referred to by its induced metric h), given the \
perturbationof the metric dg, the velocity field u (and its perturbation du):\
\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{"expr_", ",", "gauge_", ",", "order_"}], "]"}], ":=", 
  RowBox[{"ToxPand", "[", 
   RowBox[{
   "expr", ",", "dg", ",", "u", ",", "du", ",", "h", ",", " ", "gauge", ",", 
    "order"}], "]"}]}]], "Input"],

Cell["The Ricci Scalar R", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{"RicciScalarCD", "[", "]"}], ",", "\"\<AnyGauge\>\"", ",", 
    "order"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      RowBox[{"R", "[", 
       OverscriptBox["\[Del]", "_"], "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "19.788909`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", $CellContext`RicciScalarCD[] xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^(-2), " +... was performed in ", 19.788909, 
   " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {" "},
             {"\[Alpha]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[-$CellContext`\[Alpha]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {"\[Alpha]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[$CellContext`\[Alpha]],
      Editable->False]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]]}], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Alpha]", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Alpha]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[-$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Evh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Beta]", "\[Gamma]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Beta], $CellContext`\[Gamma]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], \
-$CellContext`\[Lambda], -$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Evh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Lambda]"},
                  {"\[Beta]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Lambda]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Mu]"},
               {"\[Gamma]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Mu]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Beta]", "\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Lambda], \
-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Evh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Gamma]", "\[Lambda]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Mu]"},
               {"\[Gamma]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Mu]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[-$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Beta]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[2]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], \
-$CellContext`\[Lambda], -$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Lambda]"},
                  {"\[Beta]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Lambda]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Mu]"},
               {"\[Gamma]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Beta]", "\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Lambda], \
-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Gamma]", "\[Lambda]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Mu]"},
               {"\[Gamma]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {"\[Lambda]", " ", " "},
               {" ", "\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[$CellContext`\[Lambda], -$CellContext`\[Alpha], \
-$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Gamma]", "\[Lambda]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", " "},
                  {" ", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[-$CellContext`\[Beta]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Evh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1], -$CellContext`\[Beta]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Bvh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"36", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"48", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"24", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Evh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Gamma]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Gamma]][
          $CellContext`cd[-$CellContext`\[Beta]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["Or we can restrict to the Newton gauge", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{"RicciScalarCD", "[", "]"}], ",", "\"\<NewtonGauge\>\"", ",", 
    "order"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      RowBox[{"R", "[", 
       OverscriptBox["\[Del]", "_"], "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "8.500772`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", $CellContext`RicciScalarCD[] xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^(-2), " +... was performed in ", 8.500772, 
   " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {" "},
             {"\[Alpha]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[-$CellContext`\[Alpha]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {"\[Alpha]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[$CellContext`\[Alpha]],
      Editable->False]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]]}], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Alpha]", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Alpha]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Beta]", "\[Gamma]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Beta], $CellContext`\[Gamma]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[-$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Beta]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Bvh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"The", " ", "Ricci", " ", "tensor", " ", 
  SubscriptBox["R", "\[Mu]\[Nu]"], " ", "can", " ", "also", " ", "be", " ", 
  "obtained", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
    "we", " ", "restrict", " ", "here", " ", "to", " ", "the", " ", "Newton", 
     " ", "gauge", " ", "to", " ", "avoid", " ", "too", " ", "large", " ", 
     "expressions"}], ")"}], "."}]}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{"RicciCD", "[", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], ",", 
      RowBox[{"-", "\[Nu]"}]}], "]"}], ",", "\"\<NewtonGauge\>\"", ",", "1"}],
    "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"R", "[", 
         OverscriptBox["\[Del]", "_"], "]"}], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`RicciCD[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "29.353342`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", 
   $CellContext`RicciCD[-$CellContext`\[Mu], -$CellContext`\[Nu]], 
   " +... was performed in ", 29.353342, " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Alpha]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[ScriptCapitalH]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Hh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1]],
    Editable->False]}], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[ScriptCapitalH]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Hh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Alpha]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Nu]", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
    Editable->False]}], "+", 
  InterpretationBox[
   StyleBox[
    OverscriptBox[
     InterpretationBox[
      StyleBox[GridBox[{
         {"\[Sigma]", 
          StyleBox[GridBox[{
             {" ", " "},
             {"\[Mu]", "\[Nu]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
      Editable->False], "\[Prime]"],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`Kh[
    xAct`xTensor`LI[0], 
    xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
   Editable->False], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Alpha]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Nu]", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Alpha]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{"3", " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[ScriptCapitalH]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Hh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Alpha]", "\[Beta]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Beta]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Alpha]", "\[Beta]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Beta]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Alpha]", "\[Beta]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Alpha]", "\[Beta]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Alpha]", " "},
           {" ", "\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Beta]", " "},
           {" ", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Alpha]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Alpha], \
-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Beta]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Beta]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Alpha]", " "},
           {" ", "\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Alpha]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Nu]", "\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Alpha]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Alpha], \
-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Beta]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Mu]", "\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], ")"}]}], "+", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], "\[Prime]\[Prime]"]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Eth[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[2], -$CellContext`\[Mu], -$CellContext`\[Nu]],
      Editable->False], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Mu]", "\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Mu]", "\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Mu]", "\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Nu]", "\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Alpha]"},
                 {"\[Mu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Mu]", "\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Alpha]"},
                 {"\[Nu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Alpha]],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False]}], "+", 
     RowBox[{"6", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Nu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Nu], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Nu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu]],
        Editable->False], ")"}], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "+", 
     RowBox[{"6", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Mu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Mu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "-", 
     RowBox[{"6", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Alpha]", "\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Alpha]", "\[Beta]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Gamma]"},
                 {"\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Nu]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Mu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Nu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Beta]", "\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Gamma]"},
                 {"\[Nu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Beta]", "\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Gamma]"},
                 {"\[Mu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["7", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Mu]", "\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Alpha]", "\[Beta]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Alpha]", "\[Beta]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Alpha]", "\[Beta]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Nu]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Alpha]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Nu]", "\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Mu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Nu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Nu], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["3", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Nu]", "\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Mu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["3", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Nu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Nu]", "\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Beta]", "\[Gamma]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Beta], $CellContext`\[Gamma]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Alpha]"},
                   {"\[Nu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Nu], $CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Beta]", "\[Gamma]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Alpha]"},
                   {"\[Mu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], $CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Beta]", "\[Gamma]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Beta]", "\[Gamma]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
       Editable->False]}], "+", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Mu]", "\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Alpha]", " "},
              {" ", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Beta]", " "},
              {" ", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Alpha]", " "},
              {" ", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Beta]", " "},
              {" ", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Alpha]", " "},
              {" ", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Beta]", " "},
              {" ", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Nu]", "\[Beta]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Gamma]"},
                 {"\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Gamma]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Beta]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Gamma]"},
                 {"\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Gamma]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Gamma]", " "},
              {" ", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Beta]", " "},
              {" ", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Alpha]"},
                   {"\[Nu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Nu], $CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Beta]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Beta]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Nu]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Alpha]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Nu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Nu], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Nu]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Nu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {"\[Beta]", " "},
              {" ", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Nu]", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Nu]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Alpha]"},
                   {"\[Mu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], $CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Beta]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Beta]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Alpha]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", "\[Beta]"},
                   {"\[Mu]", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Mu]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Beta]"},
                 {"\[Mu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False]}], "-", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Alpha]"},
                 {"\[Mu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Beta]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[-$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{"8", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], "\[Prime]"],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[1]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "3"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Alpha]"},
                 {"\[Mu]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{"4", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], "\[Prime]\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Alpha]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Alpha]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {"\[Gamma]", " ", " "},
               {" ", "\[Nu]", "\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[$CellContext`\[Gamma], -$CellContext`\[Nu], \
-$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Alpha]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {"\[Gamma]", " ", " "},
               {" ", "\[Mu]", "\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[$CellContext`\[Gamma], -$CellContext`\[Mu], \
-$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Alpha]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Beta]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Beta]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{"5", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"5", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[2]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[2]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Bvh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`\[Mu]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Bvh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`\[Nu]]]],
        Editable->False], ")"}]}], "-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "\[Alpha]"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"E", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Nu]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`\[Alpha]][
       $CellContext`cd[$CellContext`\[Alpha]][
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]]]],
      Editable->False], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Nu]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[-$CellContext`\[Mu]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Alpha]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[-$CellContext`\[Nu]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Mu]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Nu]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[-$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Nu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Mu]", "\[Alpha]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Alpha]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Alpha]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Alpha], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Nu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Mu]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Alpha]", "\[Beta]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Mu]", "\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Alpha]", "\[Beta]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Nu]", "\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Beta]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Mu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Mu]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Nu]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Mu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Nu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Nu]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Mu]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Nu]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Alpha]", "\[Beta]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Mu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Alpha]", "\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Mu]][
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]]],
        
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Mu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Mu]][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Nu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Mu]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Mu]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Nu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Mu]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Nu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Mu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Mu]][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Nu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Nu]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Mu]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Nu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Mu]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Mu]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Nu]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Mu]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Alpha]", "\[Beta]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Nu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Alpha]", "\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Nu]][
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]]],
        
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Nu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Nu]][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Nu]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {" "},
               {"\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Nu]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Nu]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Mu]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Nu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Nu]][
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]],
        Editable->False], ")"}]}], "-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "\[Nu]"], 
        SubscriptBox[
         OverscriptBox["D", "_"], "\[Mu]"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`\[Nu]][
       $CellContext`cd[-$CellContext`\[Mu]][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], "+", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "\[Nu]"], 
        SubscriptBox[
         OverscriptBox["D", "_"], "\[Mu]"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Psi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`\[Nu]][
       $CellContext`cd[-$CellContext`\[Mu]][
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["From which we can extract for instance the 00 part just by", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"org", "[", 
  RowBox[{"%", 
   RowBox[{"n", "[", "\[Mu]", "]"}], 
   RowBox[{"n", "[", "\[Nu]", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"xPand", "::", "makeboxes"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"For anisotropic manifolds, the second label-index can be \
only interpreted as a Lie derivative for indices down.\"\>"}]], "Message", \
"MSG"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[ScriptCapitalH]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Hh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Alpha]", "\[Beta]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           RowBox[{"(", "1", ")"}]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], "1"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Gamma]"},
                 {"\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Beta]", "\[Gamma]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
       Editable->False]}], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[2]],
        Editable->False], ")"}]}], "+", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "\[Alpha]"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`\[Alpha]][
       $CellContext`cd[$CellContext`\[Alpha]][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Beta]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["or by using the xPand built-in function", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExtractComponents", "[", 
  RowBox[{"%%", ",", "h", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<Time\>\"", ",", "\"\<Time\>\""}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[ScriptCapitalH]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Hh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1]],
    Editable->False]}], "-", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Alpha]", "\[Beta]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"A", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`avh[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Alpha]", "\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Alpha]", "\[Beta]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", "\[Gamma]"},
                 {"\[Alpha]", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"\[Epsilon]", 
            OverscriptBox["h", "-"]}], 
           StyleBox[GridBox[{
              {" ", " ", " "},
              {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {"\[Beta]", "\[Gamma]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"N", 
           StyleBox[GridBox[{
              {" ", "\[Lambda]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
       Editable->False]}], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{"3", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], "\[Prime]\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[2]],
        Editable->False], ")"}]}], "+", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["D", "_"], "\[Alpha]"], 
        SuperscriptBox[
         OverscriptBox["D", "_"], "\[Alpha]"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[-$CellContext`\[Alpha]][
       $CellContext`cd[$CellContext`\[Alpha]][
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]]],
      Editable->False], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Beta]][
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
We check that we recover the curved FL case for some special constants of \
structure ...\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"W", "[", 
    RowBox[{"-", "\[Mu]"}], "]"}], ",", 
   RowBox[{"{", "M", "}"}], ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"n", "[", "\[Mu]", "]"}], "}"}]}], ",", 
   RowBox[{"ProjectedWith", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"h", "[", 
      RowBox[{"\[Mu]", ",", 
       RowBox[{"-", "\[Alpha]"}]}], "]"}], "}"}]}]}], "]"}], "\n", 
 RowBox[{"DefConstantSymbol", "[", "\[ScriptK]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefConstantSymbol", "[", "\[ScriptH]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"AutomaticRules", "[", 
  RowBox[{"W", ",", 
   RowBox[{"MakeRule", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"W", "[", "\[Alpha]", "]"}], 
       RowBox[{"W", "[", 
        RowBox[{"-", "\[Alpha]"}], "]"}]}], ",", "1"}], "}"}], "]"}]}], 
  "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ValidateSymbol", "::", "used"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Symbol \
\[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"W\\\\\\\"\\\"}]\\)\[NoBreak] is \
already used \[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"as a tensor\\\\\\\"\\\"}]\
\\)\[NoBreak].\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ValidateSymbol", "::", "used"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Symbol \[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"\[ScriptK]\\\
\\\\\"\\\"}]\\)\[NoBreak] is already used \[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\
\\\"as a constant-symbol\\\\\\\"\\\"}]\\)\[NoBreak].\"\>"}]], "Message", \
"MSG"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ValidateSymbol", "::", "used"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Symbol \[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\\\"\[ScriptH]\\\
\\\\\"\\\"}]\\)\[NoBreak] is already used \[NoBreak]\\!\\(\\*RowBox[{\\\"\\\\\
\\\"as a constant-symbol\\\\\\\"\\\"}]\\)\[NoBreak].\"\>"}]], "Message", \
"MSG"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"   Rules \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], 
   "\[InvisibleSpace]", "\<\" have been declared as UpValues for \"\>", 
   "\[InvisibleSpace]", "W", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["   Rules ", 
   Shallow[{1, 2}], " have been declared as UpValues for ", $CellContext`W, 
   "."],
  Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
These are the cases where a Bianchi V a Bianchi VII0 and a BIanchi VIIh have \
interesting limits.
See http://arxiv.org/abs/1009.3935 for details for instance.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"RulesBianchi5", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"avh", "[", "\[Alpha]_", "]"}], ":>", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"-", " ", "\[ScriptK]"}], "]"}], 
      RowBox[{"W", "[", "\[Alpha]", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"nth", "[", 
      RowBox[{"\[Alpha]_", ",", "\[Beta]_"}], "]"}], ":>", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"RulesBianchi7o", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"avh", "[", "\[Alpha]_", "]"}], ":>", "0"}], ",", 
    RowBox[{
     RowBox[{"nth", "[", 
      RowBox[{"\[Alpha]_", ",", "\[Beta]_"}], "]"}], ":>", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], "-", 
      RowBox[{
       RowBox[{"W", "[", "\[Alpha]", "]"}], 
       RowBox[{"W", "[", "\[Beta]", "]"}]}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"RulesBianchi7h", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"avh", "[", "\[Alpha]_", "]"}], ":>", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"-", " ", "\[ScriptH]"}], "]"}], 
      RowBox[{"W", "[", "\[Alpha]", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"nth", "[", 
      RowBox[{"\[Alpha]_", ",", "\[Beta]_"}], "]"}], ":>", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], "-", 
      RowBox[{
       RowBox[{"W", "[", "\[Alpha]", "]"}], 
       RowBox[{"W", "[", "\[Beta]", "]"}]}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"RulesBianchi9", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"avh", "[", "\[Alpha]_", "]"}], "\[RuleDelayed]", "0"}], ",", 
    RowBox[{
     RowBox[{"nth", "[", 
      RowBox[{"\[Alpha]_", ",", "\[Beta]_"}], "]"}], "\[RuleDelayed]", 
     RowBox[{"2", " ", 
      RowBox[{"Sqrt", "[", "\[ScriptK]", "]"}], " ", 
      RowBox[{"h", "[", 
       RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}]}]}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["\[Alpha]", "_"]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[
      Pattern[$CellContext`\[Alpha], 
       Blank[]]],
     Editable->False], "\[RuleDelayed]", 
    RowBox[{
     SqrtBox[
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["\[ScriptK]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[ScriptK],
        Editable->False]}]], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"W", 
          StyleBox[GridBox[{
             {"\[Alpha]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`W[$CellContext`\[Alpha]],
      Editable->False]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["\[Alpha]", "_"], 
             UnderscriptBox["\[Beta]", "_"]},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[
      Pattern[$CellContext`\[Alpha], 
       Blank[]], 
      Pattern[$CellContext`\[Beta], 
       Blank[]]],
     Editable->False], "\[RuleDelayed]", "0"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["\[Alpha]", "_"]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[
      Pattern[$CellContext`\[Alpha], 
       Blank[]]],
     Editable->False], "\[RuleDelayed]", "0"}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["\[Alpha]", "_"], 
             UnderscriptBox["\[Beta]", "_"]},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[
      Pattern[$CellContext`\[Alpha], 
       Blank[]], 
      Pattern[$CellContext`\[Beta], 
       Blank[]]],
     Editable->False], "\[RuleDelayed]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {
          OverscriptBox["h", "-"], 
          StyleBox[GridBox[{
             {"\[Alpha]", "\[Beta]"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Beta]],
      Editable->False], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"W", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`W[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"W", 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`W[$CellContext`\[Beta]],
       Editable->False]}]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["\[Alpha]", "_"]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[
      Pattern[$CellContext`\[Alpha], 
       Blank[]]],
     Editable->False], "\[RuleDelayed]", 
    RowBox[{
     SqrtBox[
      RowBox[{"-", 
       InterpretationBox[
        StyleBox["\[ScriptH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH],
        Editable->False]}]], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"W", 
          StyleBox[GridBox[{
             {"\[Alpha]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`W[$CellContext`\[Alpha]],
      Editable->False]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["\[Alpha]", "_"], 
             UnderscriptBox["\[Beta]", "_"]},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[
      Pattern[$CellContext`\[Alpha], 
       Blank[]], 
      Pattern[$CellContext`\[Beta], 
       Blank[]]],
     Editable->False], "\[RuleDelayed]", 
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {
          OverscriptBox["h", "-"], 
          StyleBox[GridBox[{
             {"\[Alpha]", "\[Beta]"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Beta]],
      Editable->False], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"W", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`W[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"W", 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`W[$CellContext`\[Beta]],
       Editable->False]}]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["\[Alpha]", "_"]},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[
      Pattern[$CellContext`\[Alpha], 
       Blank[]]],
     Editable->False], "\[RuleDelayed]", "0"}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {
             UnderscriptBox["\[Alpha]", "_"], 
             UnderscriptBox["\[Beta]", "_"]},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[
      Pattern[$CellContext`\[Alpha], 
       Blank[]], 
      Pattern[$CellContext`\[Beta], 
       Blank[]]],
     Editable->False], "\[RuleDelayed]", 
    RowBox[{"2", " ", 
     SqrtBox[
      InterpretationBox[
       StyleBox["\[ScriptK]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[ScriptK],
       Editable->False]], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {
          OverscriptBox["h", "-"], 
          StyleBox[GridBox[{
             {"\[Alpha]", "\[Beta]"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Beta]],
      Editable->False]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
We can check indeed the form of the  Riemann tensor in that case\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"org", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Riemanncd", "[", 
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], ",", 
        RowBox[{"-", "\[Beta]"}], ",", 
        RowBox[{"-", "\[Mu]"}], ",", 
        RowBox[{"-", "\[Nu]"}]}], "]"}], "//", 
      RowBox[{"ToConstantsOfStructure", "[", "h", "]"}]}], "//", 
     RowBox[{"ToBianchiType", "[", "h", "]"}]}], ")"}], "/.", 
   "RulesBianchi5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"org", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Riemanncd", "[", 
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], ",", 
        RowBox[{"-", "\[Beta]"}], ",", 
        RowBox[{"-", "\[Mu]"}], ",", 
        RowBox[{"-", "\[Nu]"}]}], "]"}], "//", 
      RowBox[{"ToConstantsOfStructure", "[", "h", "]"}]}], "//", 
     RowBox[{"ToBianchiType", "[", "h", "]"}]}], ")"}], "/.", 
   "RulesBianchi7o"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"org", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Riemanncd", "[", 
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], ",", 
        RowBox[{"-", "\[Beta]"}], ",", 
        RowBox[{"-", "\[Mu]"}], ",", 
        RowBox[{"-", "\[Nu]"}]}], "]"}], "//", 
      RowBox[{"ToConstantsOfStructure", "[", "h", "]"}]}], "//", 
     RowBox[{"ToBianchiType", "[", "h", "]"}]}], ")"}], "/.", 
   "RulesBianchi7h"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"org", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Riemanncd", "[", 
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], ",", 
        RowBox[{"-", "\[Beta]"}], ",", 
        RowBox[{"-", "\[Mu]"}], ",", 
        RowBox[{"-", "\[Nu]"}]}], "]"}], "//", 
      RowBox[{"ToConstantsOfStructure", "[", "h", "]"}]}], "//", 
     RowBox[{"ToBianchiType", "[", "h", "]"}]}], ")"}], "/.", 
   "RulesBianchi9"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    InterpretationBox[
     StyleBox["\[ScriptK]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[ScriptK],
     Editable->False]}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox["\[ScriptK]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xPand`\[ScriptK],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False]}]}]], "Output"],

Cell[BoxData["0"], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    InterpretationBox[
     StyleBox["\[ScriptH]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH],
     Editable->False]}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox["\[ScriptH]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[ScriptH],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    RowBox[{"-", 
     InterpretationBox[
      StyleBox["\[ScriptH]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[ScriptH],
      Editable->False]}]], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Mu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    RowBox[{"-", 
     InterpretationBox[
      StyleBox["\[ScriptH]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[ScriptH],
      Editable->False]}]], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    RowBox[{"-", 
     InterpretationBox[
      StyleBox["\[ScriptH]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[ScriptH],
      Editable->False]}]], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Mu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    RowBox[{"-", 
     InterpretationBox[
      StyleBox["\[ScriptH]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[ScriptH],
      Editable->False]}]], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Beta]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    RowBox[{"-", 
     InterpretationBox[
      StyleBox["\[ScriptH]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[ScriptH],
      Editable->False]}]], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Mu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    RowBox[{"-", 
     InterpretationBox[
      StyleBox["\[ScriptH]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[ScriptH],
      Editable->False]}]], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Mu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"W", 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`W[-$CellContext`\[Nu]],
    Editable->False]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    InterpretationBox[
     StyleBox["\[ScriptK]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[ScriptK],
     Editable->False]}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox["\[ScriptK]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xPand`\[ScriptK],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False]}]}]], "Output"]
}, Open  ]],

Cell["\<\
Note that the VIIh case is maximally symmetric, but this is seen only using \
some dimensional identities.\
\>", "Text"],

Cell["We recover indeed the curved and Flat FL results", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MyRSplit", "=", 
  RowBox[{"SplitPerturbations", "[", 
   RowBox[{"MyR", ",", 
    RowBox[{"SplitMetric", "[", 
     RowBox[{"g", ",", "dg", ",", "h", ",", "\"\<AnyGauge\>\""}], "]"}], ",", 
    "h"}], "]"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      RowBox[{"R", "[", 
       OverscriptBox["\[Del]", "_"], "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciScalarCD[],
     Editable->False], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "18.792478`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]^(-2) $CellContext`RicciScalarCD[], 
   " +... was performed in ", 18.792478, " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {" "},
             {"\[Alpha]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[-$CellContext`\[Alpha]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {"\[Alpha]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[$CellContext`\[Alpha]],
      Editable->False]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]]}], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Alpha]", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Alpha]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[-$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Evh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Beta]", "\[Gamma]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Beta], $CellContext`\[Gamma]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], \
-$CellContext`\[Lambda], -$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Evh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Lambda]"},
                  {"\[Beta]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Lambda]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Mu]"},
               {"\[Gamma]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Mu]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Beta]", "\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Lambda], \
-$CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Evh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Gamma]", "\[Lambda]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Mu]"},
               {"\[Gamma]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Mu]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[-$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Beta]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]}]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[2]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], \
-$CellContext`\[Lambda], -$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Lambda]"},
                  {"\[Beta]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Lambda]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Mu]"},
               {"\[Gamma]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Beta]", "\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Lambda], \
-$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Beta]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Gamma]", "\[Lambda]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Mu]"},
               {"\[Gamma]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {"\[Lambda]", " ", " "},
               {" ", "\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[$CellContext`\[Lambda], -$CellContext`\[Alpha], \
-$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Gamma]", "\[Lambda]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Beta]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", " "},
                  {" ", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[-$CellContext`\[Beta]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Evh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1], -$CellContext`\[Beta]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Beta]", "\[Gamma]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Lambda]"},
               {"\[Beta]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`cd[-$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Bvh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"36", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"48", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"24", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`Evh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], $CellContext`\[Alpha]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Beta]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", "\[Gamma]"},
                  {"\[Alpha]", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Gamma]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Gamma]][
          $CellContext`cd[-$CellContext`\[Beta]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"org", "[", 
  RowBox[{
   RowBox[{"MyRSplit", "/.", 
    RowBox[{
     RowBox[{"Kh", "[", "inds___", "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
   "RulesBianchi5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"org", "[", 
  RowBox[{
   RowBox[{"MyRSplit", "/.", 
    RowBox[{
     RowBox[{"Kh", "[", "inds___", "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
   "RulesBianchi7o"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"org", "[", 
  RowBox[{
   RowBox[{"MyRSplit", "/.", 
    RowBox[{
     RowBox[{"Kh", "[", "inds___", "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
   "RulesBianchi7h"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"org", "[", 
  RowBox[{
   RowBox[{"MyRSplit", "/.", 
    RowBox[{
     RowBox[{"Kh", "[", "inds___", "]"}], "\[RuleDelayed]", "0"}]}], "/.", 
   "RulesBianchi9"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[ScriptK]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[ScriptK],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"12", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]]}], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[ScriptK]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[ScriptK],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[2]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]]}], ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"12", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]]}], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[2]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]]}], ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[ScriptH]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[ScriptH],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"12", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]]}], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[ScriptH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[ScriptH],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[2]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]]}], ")"}]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox["\[ScriptK]",
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xPand`\[ScriptK],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"12", " ", 
        SuperscriptBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], "2"], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]]}], "-", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       InterpretationBox[
        StyleBox["\[ScriptK]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[ScriptK],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"18", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[2]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[2]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Phi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[$CellContext`\[Alpha]][
           $CellContext`\[Psi]h[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbations of matter fields", "Subsection"],

Cell[CellGroupData[{

Cell["General set up for the fluid velocity", "Subsubsection"],

Cell["\<\
Similarly to SplitMetric, we have a function SplitMatter which generates the \
rules for velocity perturbations, and this can then be passed as an argument \
to SplitPerturbations\
\>", "Text"],

Cell["\<\
We can gather the rules for the metric and the rules for the matter in one \
list:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Rulesmetricmatter", "[", 
   RowBox[{"gauge_", ",", "order_"}], "]"}], ":=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"SplitMetric", "[", 
     RowBox[{"g", ",", "dg", ",", "h", ",", "gauge"}], "]"}], ",", 
    RowBox[{"SplitMatter", "[", 
     RowBox[{"u", ",", "du", ",", 
      RowBox[{"-", "1"}], ",", "h", ",", "gauge", ",", "order"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Rulesmetricmatter", "[", 
  RowBox[{"\"\<FluidComovingGauge\>\"", ",", "1"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]g", 
         StyleBox[GridBox[{
            {"1", 
             UnderscriptBox["\[Alpha]", "_"], 
             UnderscriptBox["\[Beta]", "_"]},
            {" ", " ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dg[
      xAct`xTensor`LI[1], 
      Pattern[$CellContext`\[Alpha], 
       Blank[]], 
      Pattern[$CellContext`\[Beta], 
       Blank[]]],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Alpha]", "\[Beta]"},
                   {" ", " "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[$CellContext`\[Alpha], $CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Beta]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {
             OverscriptBox["h", "-"], 
             StyleBox[GridBox[{
                {"\[Alpha]", "\[Beta]"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], "+", 
        FractionBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"\[Sigma]", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]]}], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Beta]][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}]}]}], ",", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]g", 
         StyleBox[GridBox[{
            {
             RowBox[{
              RowBox[{"(", "xAct`xPand`Private`n$189893_", ")"}], "?", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"#1", " ", ">=", " ", "2"}], " ", "&"}], " ", ")"}]}], 
             UnderscriptBox["\[Alpha]", "_"], 
             UnderscriptBox["\[Beta]", "_"]},
            {" ", " ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dg[
      xAct`xTensor`LI[
       PatternTest[
        Pattern[xAct`xPand`Private`n$189893, 
         Blank[]], # >= 2& ]], 
      Pattern[$CellContext`\[Alpha], 
       Blank[]], 
      Pattern[$CellContext`\[Beta], 
       Blank[]]],
     Editable->False], "\[Rule]", 
    RowBox[{
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"E", 
           StyleBox[GridBox[{
              {"xAct`xPand`Private`n$189893", "0", "\[Alpha]", "\[Beta]"},
              {" ", " ", " ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Eth[
        xAct`xTensor`LI[xAct`xPand`Private`n$189893], 
        xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"B", 
           StyleBox[GridBox[{
              {"xAct`xPand`Private`n$189893", "0", "\[Beta]"},
              {" ", " ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Bvh[
        xAct`xTensor`LI[xAct`xPand`Private`n$189893], 
        xAct`xTensor`LI[0], $CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"B", 
           StyleBox[GridBox[{
              {"xAct`xPand`Private`n$189893", "0", "\[Alpha]"},
              {" ", " ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Bvh[
        xAct`xTensor`LI[xAct`xPand`Private`n$189893], 
        xAct`xTensor`LI[0], $CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Phi]", 
           StyleBox[GridBox[{
              {"xAct`xPand`Private`n$189893", "0"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[xAct`xPand`Private`n$189893], 
        xAct`xTensor`LI[0]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {
             OverscriptBox["h", "-"], 
             StyleBox[GridBox[{
                {"\[Alpha]", "\[Beta]"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Beta]],
         Editable->False], "+", 
        FractionBox[
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"\[Sigma]", 
                 StyleBox[GridBox[{
                    {"\[Alpha]", "\[Beta]"},
                    {" ", " "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
          Editable->False], 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]]}], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Psi]", 
           StyleBox[GridBox[{
              {"xAct`xPand`Private`n$189893", "0"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Psi]h[
        xAct`xTensor`LI[xAct`xPand`Private`n$189893], 
        xAct`xTensor`LI[0]],
       Editable->False]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], GridBox[{
            {"B", 
             StyleBox[GridBox[{
                {"xAct`xPand`Private`n$189893", "0"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`Bsh[
          xAct`xTensor`LI[xAct`xPand`Private`n$189893], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], GridBox[{
            {"B", 
             StyleBox[GridBox[{
                {"xAct`xPand`Private`n$189893", "0"},
                {" ", " "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Beta]][
         $CellContext`Bsh[
          xAct`xTensor`LI[xAct`xPand`Private`n$189893], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {
              UnderscriptBox[
               UnderscriptBox["\[Alpha]", "_"], "_"]},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[
       PatternTest[
        Pattern[$CellContext`\[Alpha], 
         Blank[]], TangentM`pmQ]],
      Editable->False], "]"}], "\[RuleDelayed]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[$CellContext`\[Alpha]],
       Editable->False]}], "]"}]}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"\[Delta]u", 
          StyleBox[GridBox[{
             {"1", 
              UnderscriptBox[
               UnderscriptBox["\[Alpha]", "_"], "_"]},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`du[
       xAct`xTensor`LI[1], 
       PatternTest[
        Pattern[$CellContext`\[Alpha], 
         Blank[]], TangentM`pmQ]],
      Editable->False], "]"}], "\[RuleDelayed]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         StyleBox[GridBox[{
            {
             OverscriptBox["n", "-"], 
             StyleBox[GridBox[{
                {"\[Alpha]"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`n[$CellContext`\[Alpha]],
         Editable->False], " ", 
        RowBox[{"Module", "[", 
         RowBox[{
          RowBox[{"{", "}"}], ",", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              StyleBox["(",
               FontColor->RGBColor[1, 0, 0]], 
              RowBox[{
               InterpretationBox[
                StyleBox[GridBox[{
                   {"\[Delta]g", 
                    StyleBox[GridBox[{
                    {"1", " ", " "},
                    {" ", "\[Alpha]", "\[Beta]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                  },
                  
                  GridBoxAlignment->{
                   "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`dg[
                 xAct`xTensor`LI[
                 1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
                Editable->False], " ", 
               InterpretationBox[
                StyleBox[GridBox[{
                   {
                    OverscriptBox["n", "-"], 
                    StyleBox[GridBox[{
                    {"\[Alpha]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                  },
                  
                  GridBoxAlignment->{
                   "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`n[$CellContext`\[Alpha]],
                Editable->False], " ", 
               InterpretationBox[
                StyleBox[GridBox[{
                   {
                    OverscriptBox["n", "-"], 
                    StyleBox[GridBox[{
                    {"\[Beta]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                  },
                  
                  GridBoxAlignment->{
                   "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`n[$CellContext`\[Beta]],
                Editable->False]}], 
              StyleBox[")",
               FontColor->RGBColor[1, 0, 0]]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xTensor`Scalar[$CellContext`dg[
               xAct`xTensor`LI[
               
               1], -$CellContext`\[Alpha], -$CellContext`\[Beta]] \
$CellContext`n[$CellContext`\[Alpha]] $CellContext`n[$CellContext`\[Beta]]],
            Editable->False]}]}], "]"}]}], "+", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {"\[Alpha]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha]],
        Editable->False], "-", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False]}]}], "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
But again it is much simpler to use the function MyxPand (based on xPand) \
which does everything.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{"u", "[", "\[Nu]", "]"}], ",", "\"\<NewtonGauge\>\"", ",", 
    "order"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     StyleBox["\[Epsilon]",
      FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"\[Delta]u", 
          StyleBox[GridBox[{
             {"1", "\[Nu]"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`du[
       xAct`xTensor`LI[1], $CellContext`\[Nu]],
      Editable->False]}], 
    InterpretationBox[
     StyleBox[
      RowBox[{
       StyleBox["(",
        FontColor->RGBColor[1, 0, 0]], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], 
       StyleBox[")",
        FontColor->RGBColor[1, 0, 0]]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]],
     Editable->False]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.128619`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", xAct`xPand`\[Epsilon] $CellContext`du[
     xAct`xTensor`LI[1], $CellContext`\[Nu]]/xAct`xTensor`Scalar[
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]]], " +... was performed in ", 0.128619, " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {"\[Nu]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[$CellContext`\[Nu]],
    Editable->False], 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"Vu", 
               StyleBox[GridBox[{
                  {"\[Nu]"},
                  {" "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vvhu[$CellContext`\[Nu]],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Vvhu[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0], $CellContext`\[Nu]],
       Editable->False], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox[
          OverscriptBox["D", "_"], "\[Nu]"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["Vu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vshu[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`\[Nu]][
        $CellContext`Vshu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Divergence of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"the", " ", "velocity", " ", 
    RowBox[{"field", " ", ":", " ", 
     RowBox[{
      SubscriptBox["\[Del]", "\[Mu]"], " ", 
      SuperscriptBox["u", "\[Mu]"]}]}]}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"CD", "[", 
      RowBox[{"-", "\[Nu]"}], "]"}], "@", 
     RowBox[{"u", "[", "\[Nu]", "]"}]}], ",", "\"\<NewtonGauge\>\"", ",", 
    "order"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"3", " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"\[Nu]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`\[Nu]],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["\[Del]", "_"], "\[Nu]"], 
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`\[Nu]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.358824`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", 3 xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[
       0]]]^(-2) $CellContext`u[$CellContext`\[Nu]] \
$CellContext`CD[-$CellContext`\[Nu]][
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]], " +... was performed in ", 0.358824, " seconds."],
  
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]}], 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]]}], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     FractionBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "\[Alpha]"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "\[Alpha]"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["Vu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vshu[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`\[Alpha]][
        $CellContext`cd[$CellContext`\[Alpha]][
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Acceleration", " ", "of", "  ", 
   SuperscriptBox["A", "\[Nu]"]}], "=", 
  RowBox[{
   SuperscriptBox["u", "\[Mu]"], 
   FormBox[
    RowBox[{
     SubscriptBox["\[Del]", "\[Mu]"], " ", 
     SuperscriptBox["u", "\[Nu]"]}],
    TraditionalForm]}]}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"u", "[", "\[Mu]", "]"}], 
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "\[Mu]"}], "]"}], "@", 
      RowBox[{"u", "[", "\[Nu]", "]"}]}]}], ",", "\"\<NewtonGauge\>\"", ",", 
    "order"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"\[Mu]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`\[Mu]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"\[Nu]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`\[Nu]],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["\[Del]", "_"], "\[Mu]"], 
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`\[Mu]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "3"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.655239`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[
       0]]]^(-3) $CellContext`u[$CellContext`\[Mu]] \
$CellContext`u[$CellContext`\[Nu]] $CellContext`CD[-$CellContext`\[Mu]][
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]], " +... was performed in ", 0.655239, " seconds."],
  
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  StyleBox["\[Epsilon]",
   FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Alpha]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {"\[Nu]", "\[Alpha]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[$CellContext`\[Nu], $CellContext`\[Alpha]],
       Editable->False]}], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]], "+", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {"\[Nu]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Nu]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]}], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]], "+", 
    FractionBox[
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {"\[Nu]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[$CellContext`\[Nu]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Nu]],
        Editable->False], ")"}]}], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]], "+", 
    FractionBox[
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {"\[Nu]", "\[Alpha]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[$CellContext`\[Nu], $CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[-$CellContext`\[Alpha]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
        Editable->False], ")"}]}], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]], "+", 
    FractionBox[
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Nu]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Nu]][
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]], "+", 
    FractionBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "\[Nu]"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["Vu",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Vshu[],
          Editable->False], "\[Prime]"]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`\[Nu]][
       $CellContext`Vshu[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]]],
      Editable->False], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]], "+", 
    FractionBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        SuperscriptBox[
         OverscriptBox["D", "_"], "\[Nu]"], 
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Phi]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`cd[$CellContext`\[Nu]][
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]]],
      Editable->False], 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]]}], ")"}]}]], "Output"]
}, Open  ]],

Cell["The shear of the velocity field", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{"STFPart", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"CD", "[", 
        RowBox[{"-", "\[Alpha]"}], "]"}], "[", 
       RowBox[{"u", "[", 
        RowBox[{"-", "\[Beta]"}], "]"}], "]"}], ",", "h"}], "]"}], ",", 
    "\"\<NewtonGauge\>\"", ",", "order"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"u", 
         StyleBox[GridBox[{
            {" "},
            {"\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`u[-$CellContext`\[Beta]],
     Editable->False], " ", 
    RowBox[{"(", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        SubscriptBox[
         OverscriptBox["\[Del]", "_"], "\[Alpha]"], 
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`CD[-$CellContext`\[Alpha]][
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], ")"}]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "2.652746`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", 
   Rational[-1, 
     2] $CellContext`u[-$CellContext`\[Beta]] $CellContext`CD[-$CellContext`\
\[Alpha]][
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]], " +... was performed in ", 2.652746, " seconds."],
  
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["a",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`ah[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Alpha]", "\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Beta]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Alpha]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[-$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[-$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {"\[Gamma]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[$CellContext`\[Gamma]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {"\[Gamma]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[$CellContext`\[Gamma]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[-$CellContext`\[Alpha]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[-$CellContext`\[Beta]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Vvhu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Beta]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["2", "3"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[-$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Vvhu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Beta]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"Vu", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vvhu[-$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Vvhu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Gamma]"], 
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Gamma]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Gamma]][
         $CellContext`cd[$CellContext`\[Gamma]][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Gamma]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Gamma]][
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Gamma]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["Vu",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Vshu[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Gamma]][
         $CellContext`Vshu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stress - energy Tensor", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"Tmunu", "[", 
    RowBox[{
     RowBox[{"-", "\[Mu]"}], ",", 
     RowBox[{"-", "\[Nu]"}]}], "]"}], ",", "M"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tmunu", "[", 
   RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Rho]", "[", "u", "]"}], "[", "]"}], "+", 
      RowBox[{
       RowBox[{"P", "[", "u", "]"}], "[", "]"}]}], ")"}], 
    RowBox[{"u", "[", "\[Mu]", "]"}], 
    RowBox[{"u", "[", "\[Nu]", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"P", "[", "u", "]"}], "[", "]"}], 
    RowBox[{"g", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]}]}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Tmunu", "[", 
    RowBox[{
     RowBox[{"-", "\[Mu]"}], ",", 
     RowBox[{"-", "\[Nu]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Tmunu[-$CellContext`\[Mu], -$CellContext`\[Nu]], ". ", ""],
  Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MyxPand", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"CD", "[", 
     RowBox[{"-", "\[Mu]"}], "]"}], "@", 
    RowBox[{"Tmunu", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], ",", "\"\<NewtonGauge\>\"", 
   ",", "order"}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    RowBox[{"4", " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["Pu",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Pu[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Pu[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"\[Mu]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`\[Mu]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"u", 
          StyleBox[GridBox[{
             {"\[Nu]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`u[$CellContext`\[Nu]],
      Editable->False], " ", 
     RowBox[{"(", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["\[Del]", "_"], "\[Mu]"], 
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`CD[-$CellContext`\[Mu]][
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]]],
       Editable->False], ")"}]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "3"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "2.875167`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", 4 $CellContext`Pu[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]] xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[
       0]]]^(-3) $CellContext`u[$CellContext`\[Mu]] \
$CellContext`u[$CellContext`\[Nu]] $CellContext`CD[-$CellContext`\[Mu]][
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]]], " +... was performed in ", 2.875167, " seconds."],
  
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Nu]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["Pu",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Pu[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[ScriptCapitalH]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Hh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Nu]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[Rho]u",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Rho]u[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Nu]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["\[Rho]u",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`\[Rho]u[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Mu]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[-$CellContext`\[Mu]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Mu]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]", "\[Mu]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[$CellContext`\[Nu], $CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[$CellContext`\[Nu]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Nu]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[$CellContext`\[Nu]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Nu]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Pu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"Vu", 
                 StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vvhu[$CellContext`\[Nu]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Vvhu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Nu]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"Vu", 
                 StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vvhu[$CellContext`\[Nu]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Vvhu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Nu]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]", "\[Mu]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[$CellContext`\[Nu], $CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"Vu", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Mu]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vvhu[-$CellContext`\[Mu]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Vvhu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Mu]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Mu]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[-$CellContext`\[Mu]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Mu]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]", "\[Mu]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[$CellContext`\[Nu], $CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[$CellContext`\[Nu]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Nu]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"Vu", 
                 StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vvhu[$CellContext`\[Nu]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Vvhu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Nu]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]", "\[Mu]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[$CellContext`\[Nu], $CellContext`\[Mu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"Vu", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Mu]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vvhu[-$CellContext`\[Mu]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Vvhu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Mu]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"Vu", 
                 StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vvhu[$CellContext`\[Nu]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Vvhu[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Nu]],
         Editable->False], ")"}], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Rho]u[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Rho]u[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Vu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Mu]][
          $CellContext`cd[$CellContext`\[Mu]][
           $CellContext`Vshu[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Nu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Nu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Vu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Mu]][
          $CellContext`cd[$CellContext`\[Mu]][
           $CellContext`Vshu[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         SuperscriptBox[
          OverscriptBox["D", "_"], "\[Nu]"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[$CellContext`\[Nu]][
        $CellContext`Pu[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]]],
       Editable->False], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Vu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Vu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Vu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Vu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Vu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Vu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Vshu[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`Vshu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExtractComponents", "[", 
  RowBox[{
   RowBox[{"%", 
    RowBox[{
     RowBox[{"ah", "[", "]"}], "^", "2"}]}], ",", "h"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"n", 
     RowBox[{
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["Pu",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Pu[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Rho]u",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Rho]u[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]}], "+", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[Rho]u",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[],
          Editable->False], "\[Prime]"],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Rho]u[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[1]],
       Editable->False], "+", 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["Pu",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Pu[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Pu[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}]}], "+", 
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Rho]u",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Rho]u[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Rho]u[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}]}], "+", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]u",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], "\[Prime]"]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], "-", 
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["Pu",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Pu[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}]}], "-", 
         RowBox[{"6", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]u",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}]}], "-", 
         RowBox[{"2", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]u",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], "\[Prime]"],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[1]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Phi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Phi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}]}], "-", 
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["Pu",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Pu[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Psi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Psi]h[],
                Editable->False], "\[Prime]"]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]],
            Editable->False], ")"}]}], "-", 
         RowBox[{"3", " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]u",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Psi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Psi]h[],
                Editable->False], "\[Prime]"]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]],
            Editable->False], ")"}]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["Pu",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Pu[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Pu[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "\[Mu]"], 
              SuperscriptBox[
               OverscriptBox["D", "_"], "\[Mu]"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["Vu",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Vshu[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`\[Mu]][
             $CellContext`cd[$CellContext`\[Mu]][
              $CellContext`Vshu[
               xAct`xTensor`LI[1], 
               xAct`xTensor`LI[0]]]],
            Editable->False], ")"}]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Rho]u",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Rho]u[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Rho]u[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              SubscriptBox[
               OverscriptBox["D", "_"], "\[Mu]"], 
              SuperscriptBox[
               OverscriptBox["D", "_"], "\[Mu]"], 
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["Vu",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Vshu[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`cd[-$CellContext`\[Mu]][
             $CellContext`cd[$CellContext`\[Mu]][
              $CellContext`Vshu[
               xAct`xTensor`LI[1], 
               xAct`xTensor`LI[0]]]],
            Editable->False], ")"}]}]}], ")"}]}]}]},
    {"h", 
     RowBox[{
      StyleBox["\[Epsilon]",
       FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"B", 
                   StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bvh[-$CellContext`\[Alpha]],
               Editable->False], "\[Prime]"]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bvh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {
              OverscriptBox["h", "-"], 
              StyleBox[GridBox[{
                 {"\[Nu]", "\[Alpha]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h[$CellContext`\[Nu], $CellContext`\[Alpha]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"B", 
                   StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bvh[$CellContext`\[Nu]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bvh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Nu]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"B", 
                   StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bvh[$CellContext`\[Nu]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bvh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Nu]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], "\[Prime]"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"Vu", 
                   StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vvhu[$CellContext`\[Nu]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vvhu[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Nu]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], "\[Prime]"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"Vu", 
                   StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vvhu[$CellContext`\[Nu]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vvhu[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Nu]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {
              OverscriptBox["h", "-"], 
              StyleBox[GridBox[{
                 {"\[Nu]", "\[Alpha]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h[$CellContext`\[Nu], $CellContext`\[Alpha]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"Vu", 
                   StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vvhu[-$CellContext`\[Alpha]],
               Editable->False], "\[Prime]"]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vvhu[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"B", 
                   StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bvh[-$CellContext`\[Alpha]],
               Editable->False], "\[Prime]"]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bvh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[GridBox[{
             {
              OverscriptBox["h", "-"], 
              StyleBox[GridBox[{
                 {"\[Nu]", "\[Alpha]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h[$CellContext`\[Nu], $CellContext`\[Alpha]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"B", 
                   StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bvh[$CellContext`\[Nu]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bvh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Nu]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"Vu", 
                   StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vvhu[$CellContext`\[Nu]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vvhu[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Nu]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[GridBox[{
             {
              OverscriptBox["h", "-"], 
              StyleBox[GridBox[{
                 {"\[Nu]", "\[Alpha]"},
                 {" ", " "}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`h[$CellContext`\[Nu], $CellContext`\[Alpha]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"Vu", 
                   StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vvhu[-$CellContext`\[Alpha]],
               Editable->False], "\[Prime]"]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vvhu[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False]}], "+", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"Vu", 
                   StyleBox[GridBox[{
                    {"\[Nu]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vvhu[$CellContext`\[Nu]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Vvhu[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Nu]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], "\[Prime]"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False]}], "+", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Nu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Nu]][
          $CellContext`Pu[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Nu]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["Vu",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vshu[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Nu]][
            $CellContext`Vshu[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], "\[Prime]"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Nu]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["Vu",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vshu[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Nu]][
            $CellContext`Vshu[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}], "+", 
        RowBox[{"4", " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[ScriptCapitalH]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Hh[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Nu]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["Vu",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vshu[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Nu]][
            $CellContext`Vshu[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], "\[Prime]"],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[1]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Nu]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["Vu",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vshu[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Nu]][
            $CellContext`Vshu[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Nu]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["Vu",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vshu[],
               Editable->False], "\[Prime]"]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Nu]][
            $CellContext`Vshu[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Nu]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["Vu",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Vshu[],
               Editable->False], "\[Prime]"]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Nu]][
            $CellContext`Vshu[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["Pu",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Pu[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Pu[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Nu]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]h[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Nu]][
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Rho]u",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Rho]u[],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Rho]u[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Nu]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["\[Phi]",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`\[Phi]h[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Nu]][
            $CellContext`\[Phi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}]}], ")"}]}]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output"]
}, Open  ]],

Cell["KleinGordon equation", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "V", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DefScalarFunction", "[", "V", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ConformalWeight", "[", 
    RowBox[{"V", "'"}], "]"}], "=", "0"}], ";"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "V", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`V, ". ", ""],
  Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"CD", "[", 
       RowBox[{"-", "\[Mu]"}], "]"}], "@", 
      RowBox[{
       RowBox[{"CD", "[", "\[Mu]", "]"}], "[", 
       RowBox[{"\[CurlyPhi]", "[", "]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"V", "'"}], "[", 
      RowBox[{"\[CurlyPhi]", "[", "]"}], "]"}]}], ",", "\"\<AnyGauge\>\"", 
    ",", "order"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox[
    InterpretationBox[
     StyleBox[
      RowBox[{
       SubscriptBox[
        OverscriptBox["\[Del]", "_"], "\[Mu]"], 
       SuperscriptBox[
        OverscriptBox["\[Del]", "_"], "\[Mu]"], 
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`CD[-$CellContext`\[Mu]][
      $CellContext`CD[$CellContext`\[Mu]][
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]]],
     Editable->False], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "2.283594`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^(-2) $CellContext`CD[-$CellContext`\[Mu]][
     $CellContext`CD[$CellContext`\[Mu]][
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]], " +... was performed in ", 2.283594, 
   " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[ScriptCapitalH]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Hh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["\[CurlyPhi]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         xAct`xPand`\[CurlyPhi][],
         Editable->False], "\[Prime]"],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xPand`\[CurlyPhi][
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[1]],
      Editable->False]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]]}], "-", 
  FractionBox[
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[CurlyPhi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][],
       Editable->False], "\[Prime]\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xPand`\[CurlyPhi][
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[2]],
    Editable->False], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox["V",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`V,
     Editable->False], "\[Prime]",
    MultilineFunction->None], "[", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox["\[CurlyPhi]",
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xPand`\[CurlyPhi][
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0]],
    Editable->False], "]"}], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[ScriptCapitalH]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Hh[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Hh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[CurlyPhi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              xAct`xPand`\[CurlyPhi][],
              Editable->False], "\[Prime]"]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          xAct`xPand`\[CurlyPhi][
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], ")"}]}], 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"]]}], "-", 
     FractionBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]\[Prime]"]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xPand`\[CurlyPhi][
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[2]],
       Editable->False], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[2]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Phi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Phi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Phi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Mu]", "\[Alpha]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Mu], $CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Mu], $CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`cd[-$CellContext`\[Mu]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"A", 
            StyleBox[GridBox[{
               {"\[Mu]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`avh[$CellContext`\[Mu]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Mu]", "\[Alpha]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Alpha]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Mu]][
          $CellContext`cd[$CellContext`\[Mu]][
           $CellContext`Bsh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "-", 
     FractionBox[
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Mu]][
          $CellContext`cd[$CellContext`\[Mu]][
           $CellContext`Esh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1]]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "\[Mu]"], 
         SuperscriptBox[
          OverscriptBox["D", "_"], "\[Mu]"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`\[Mu]][
        $CellContext`cd[$CellContext`\[Mu]][
         xAct`xPand`\[CurlyPhi][
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            RowBox[{"\[Epsilon]", 
             OverscriptBox["h", "-"]}], 
            StyleBox[GridBox[{
               {" ", " ", " "},
               {"\[Mu]", "\[Beta]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {"\[Alpha]", "\[Beta]"},
                  {" ", " "}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"N", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Alpha]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], "\[Prime]"],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[1]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Mu]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["E",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Esh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Mu]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"]], "+", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[CurlyPhi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            xAct`xPand`\[CurlyPhi][],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}], " ", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["V",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`V,
         Editable->False], "\[Prime]\[Prime]",
        MultilineFunction->None], "[", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[CurlyPhi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           xAct`xPand`\[CurlyPhi][],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xPand`\[CurlyPhi][
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "]"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gauge Transformation", "Section"],

Cell["\<\
Gauge transformation fields, split in 1 + 3 on the background. The spatial \
part is then split into Scalar and Vector parts\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"\[Xi]", "[", 
    RowBox[{
     RowBox[{"LI", "[", "ord", "]"}], ",", "\[Alpha]"}], "]"}], ",", "M"}], 
  "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Xi]", "[", 
    RowBox[{
     RowBox[{"LI", "[", "ord", "]"}], ",", "\[Alpha]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   xAct`xPand`\[Xi][
    xAct`xTensor`LI[$CellContext`ord], $CellContext`\[Alpha]], ". ", ""],
  Editable->False]], "Print"]
}, Open  ]],

Cell["The gauge transformation to go in the Newtonian gauge", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RulesGaugeField", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Xi]", "[", 
     RowBox[{
      RowBox[{"LI", "[", "ord_", "]"}], ",", "\[Alpha]_"}], "]"}], ":>", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Bsh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "ord", "]"}], ",", 
          RowBox[{"LI", "[", "0", "]"}]}], "]"}], " ", "-", " ", 
        RowBox[{"Esh", "[", 
         RowBox[{
          RowBox[{"LI", "[", "ord", "]"}], ",", 
          RowBox[{"LI", "[", "1", "]"}]}], "]"}]}], ")"}], 
      RowBox[{"n", "[", "\[Alpha]", "]"}]}], "-", 
     RowBox[{"Evh", "[", 
      RowBox[{
       RowBox[{"LI", "[", "ord", "]"}], ",", 
       RowBox[{"LI", "[", "0", "]"}], ",", "\[Alpha]"}], "]"}], "-", 
     RowBox[{
      RowBox[{"cd", "[", "\[Alpha]", "]"}], "[", 
      RowBox[{"Esh", "[", 
       RowBox[{
        RowBox[{"LI", "[", "ord", "]"}], ",", 
        RowBox[{"LI", "[", "0", "]"}]}], "]"}], "]"}]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    StyleBox[GridBox[{
       {"\[Xi]", 
        StyleBox[GridBox[{
           {"ord_", 
            UnderscriptBox["\[Alpha]", "_"]},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xPand`\[Xi][
     xAct`xTensor`LI[
      Pattern[$CellContext`ord, 
       Blank[]]], 
     Pattern[$CellContext`\[Alpha], 
      Blank[]]],
    Editable->False], "\[RuleDelayed]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {"B", 
            StyleBox[GridBox[{
               {"ord", "0"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bsh[
         xAct`xTensor`LI[$CellContext`ord], 
         xAct`xTensor`LI[0]],
        Editable->False], "-", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"E", 
            StyleBox[GridBox[{
               {"ord", "1"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Esh[
         xAct`xTensor`LI[$CellContext`ord], 
         xAct`xTensor`LI[1]],
        Editable->False]}], ")"}], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {
          OverscriptBox["n", "-"], 
          StyleBox[GridBox[{
             {"\[Alpha]"},
             {" "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`n[$CellContext`\[Alpha]],
      Editable->False]}], "-", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"E", 
         StyleBox[GridBox[{
            {"ord", "0", "\[Alpha]"},
            {" ", " ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Evh[
      xAct`xTensor`LI[$CellContext`ord], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha]],
     Editable->False], "-", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox[
        OverscriptBox["D", "_"], "\[Alpha]"], GridBox[{
         {"E", 
          StyleBox[GridBox[{
             {"ord", "0"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[$CellContext`\[Alpha]][
      $CellContext`Esh[
       xAct`xTensor`LI[$CellContext`ord], 
       xAct`xTensor`LI[0]]],
     Editable->False]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Xi]", "[", 
   RowBox[{
    RowBox[{"LI", "[", "1", "]"}], ",", "\[Alpha]"}], "]"}], "/.", 
  "RulesGaugeField"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       OverscriptBox["\[Null]", 
        StyleBox[
         RowBox[{"(", "1", ")"}],
         FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"E", 
             StyleBox[GridBox[{
                {"\[Alpha]"},
                {" "}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Evh[$CellContext`\[Alpha]],
         Editable->False], ""]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Evh[
      xAct`xTensor`LI[1], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha]],
     Editable->False], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["B",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[],
          Editable->False], ""]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Bsh[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[0]],
      Editable->False], "-", 
     InterpretationBox[
      StyleBox[
       RowBox[{
        OverscriptBox["\[Null]", 
         StyleBox[
          RowBox[{"(", "1", ")"}],
          FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
        OverscriptBox[
         InterpretationBox[
          StyleBox["E",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Esh[],
          Editable->False], "\[Prime]"]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Esh[
       xAct`xTensor`LI[1], 
       xAct`xTensor`LI[1]],
      Editable->False]}], ")"}], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {"\[Alpha]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[$CellContext`\[Alpha]],
    Editable->False]}], "-", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SuperscriptBox[
      OverscriptBox["D", "_"], "\[Alpha]"], 
     OverscriptBox["\[Null]", 
      StyleBox[
       RowBox[{"(", "1", ")"}],
       FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
     OverscriptBox[
      InterpretationBox[
       StyleBox["E",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Esh[],
       Editable->False], ""]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`cd[$CellContext`\[Alpha]][
    $CellContext`Esh[
     xAct`xTensor`LI[1], 
     xAct`xTensor`LI[0]]],
   Editable->False]}]], "Output"]
}, Open  ]],

Cell["If we use the GaugeChange function of xPert", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GaugeChange", "[", 
  RowBox[{
   RowBox[{"dg", "[", 
    RowBox[{
     RowBox[{"LI", "[", "1", "]"}], ",", 
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], ",", "\[Xi]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"\[Delta]g", 
       StyleBox[GridBox[{
          {"1", " ", " "},
          {" ", "\[Alpha]", "\[Beta]"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`dg[
    xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
   Editable->False], "+", 
  InterpretationBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[ScriptCapitalL]", GridBox[{
        {"\[Xi]", 
         StyleBox[GridBox[{
            {"1"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}]], GridBox[{
       {
        OverscriptBox["g", "_"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   xAct`xTensor`LieD[
    xAct`xPand`\[Xi][
     xAct`xTensor`LI[1], $CellContext`\[Alpha]]][
    $CellContext`g[-$CellContext`\[Alpha], -$CellContext`\[Beta]]],
   Editable->False]}]], "Output"]
}, Open  ]],

Cell["\<\
We see that we need to split the result after specifying what is the \
perturbation of the metric.
This is done by SplitGaugeChange\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplitGaugeChange", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], ",", 
   RowBox[{"Join", "[", 
    RowBox[{"RulesGaugeField", ",", 
     RowBox[{"Rulesmetricmatter", "[", 
      RowBox[{"\"\<AnyGauge\>\"", ",", "order"}], "]"}]}], "]"}], ",", 
   "\[Xi]", ",", "h", ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    StyleBox["\[Epsilon]",
     FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]g", 
         StyleBox[GridBox[{
            {"1", " ", " "},
            {" ", "\[Alpha]", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dg[
      xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "0.996187`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", xAct`xPand`\[Epsilon] $CellContext`dg[
     xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]] 
   xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^2, " +... was performed in ", 0.996187, 
   " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Alpha]", "\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["E",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Esh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["E",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Esh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False]}], "+", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Evh[-$CellContext`\[Beta]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Evh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Gamma]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Evh[$CellContext`\[Gamma]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Evh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Evh[-$CellContext`\[Alpha]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Evh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {"\[Gamma]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Evh[$CellContext`\[Gamma]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Evh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["E",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[],
            Editable->False], "\[Prime]\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Esh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[2]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bsh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["E",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Esh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Gamma]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["E",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Gamma]][
         $CellContext`Esh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Gamma]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["E",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Gamma]][
         $CellContext`Esh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell["\<\
Indeed, we can check that after the gauge transformation, the result is in \
the Newtonian gauge\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExtractComponents", "[", 
  RowBox[{
   RowBox[{"%", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       RowBox[{"ah", "[", "]"}], "^", "2"}]}], ")"}]}], ",", "h"}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"", "n", "h"},
    {"n", 
     RowBox[{
      FractionBox["1", "2"], "+", 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["B",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Bsh[],
              Editable->False], "\[Prime]"]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]],
          Editable->False], "-", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["E",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Esh[],
              Editable->False], "\[Prime]\[Prime]"]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[2]],
          Editable->False], "+", 
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "-", 
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["E",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Esh[],
                Editable->False], "\[Prime]"]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]],
            Editable->False], ")"}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "+", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Phi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Phi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Phi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False]}], ")"}]}]}], 
     RowBox[{
      StyleBox["\[Epsilon]",
       FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"B", 
                   StyleBox[GridBox[{
                    {" "},
                    {"\[Beta]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bvh[-$CellContext`\[Beta]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bvh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], -$CellContext`\[Beta]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"E", 
                   StyleBox[GridBox[{
                    {" "},
                    {"\[Beta]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Evh[-$CellContext`\[Beta]],
               Editable->False], "\[Prime]"]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Evh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1], -$CellContext`\[Beta]],
           Editable->False], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"E", 
                   StyleBox[GridBox[{
                    {"\[Gamma]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Evh[$CellContext`\[Gamma]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Evh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Gamma]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"\[Sigma]", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Beta]", "\[Gamma]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
          
          Editable->False]}], "-", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"\[Sigma]", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Beta]", "\[Gamma]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
          
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Gamma]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["E",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Esh[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Gamma]][
            $CellContext`Esh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}]}], ")"}]}]},
    {"h", 
     RowBox[{
      StyleBox["\[Epsilon]",
       FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"B", 
                   StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Bvh[-$CellContext`\[Alpha]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Bvh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
           Editable->False], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"E", 
                   StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Evh[-$CellContext`\[Alpha]],
               Editable->False], "\[Prime]"]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Evh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
           Editable->False], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"E", 
                   StyleBox[GridBox[{
                    {"\[Gamma]"},
                    {" "}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Evh[$CellContext`\[Gamma]],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Evh[
            xAct`xTensor`LI[1], 
            xAct`xTensor`LI[0], $CellContext`\[Gamma]],
           Editable->False], ")"}], " ", 
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"\[Sigma]", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Gamma]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
          Editable->False]}], "-", 
        RowBox[{
         InterpretationBox[
          StyleBox[
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"\[Sigma]", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Gamma]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
             Editable->False], ""],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[
           xAct`xTensor`LI[0], 
           xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
          Editable->False], " ", 
         RowBox[{"(", 
          InterpretationBox[
           StyleBox[
            RowBox[{
             SuperscriptBox[
              OverscriptBox["D", "_"], "\[Gamma]"], 
             OverscriptBox["\[Null]", 
              StyleBox[
               RowBox[{"(", "1", ")"}],
               FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
             OverscriptBox[
              InterpretationBox[
               StyleBox["E",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Esh[],
               Editable->False], ""]}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`cd[$CellContext`\[Gamma]][
            $CellContext`Esh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]]],
           Editable->False], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False]}], "+", 
      RowBox[{
       StyleBox["\[Epsilon]",
        FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox[GridBox[{
                   {"E", 
                    StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                  },
                  
                  GridBoxAlignment->{
                   "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Eth[-$CellContext`\[Alpha], \
-$CellContext`\[Beta]],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[
             0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {
               OverscriptBox["h", "-"], 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "+", 
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["E",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Esh[],
                Editable->False], "\[Prime]"]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]],
            Editable->False], ")"}], " ", 
          InterpretationBox[
           StyleBox[GridBox[{
              {
               OverscriptBox["h", "-"], 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]}], "-", 
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["B",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Bsh[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"\[Sigma]", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False]}], "+", 
         RowBox[{
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["E",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`Esh[],
                Editable->False], "\[Prime]"]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[1]],
            Editable->False], ")"}], " ", 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox[GridBox[{
                 {"\[Sigma]", 
                  StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                   FontSize->Rational[39, 4]]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False]}], "+", 
         RowBox[{
          InterpretationBox[
           StyleBox[GridBox[{
              {
               OverscriptBox["h", "-"], 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], " ", 
          RowBox[{"(", 
           InterpretationBox[
            StyleBox[
             RowBox[{
              OverscriptBox["\[Null]", 
               StyleBox[
                RowBox[{"(", "1", ")"}],
                FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
              OverscriptBox[
               InterpretationBox[
                StyleBox["\[Psi]",
                 ShowAutoStyles->False,
                 AutoSpacing->False],
                $CellContext`\[Psi]h[],
                Editable->False], ""]}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[
             xAct`xTensor`LI[1], 
             xAct`xTensor`LI[0]],
            Editable->False], ")"}]}], "+", 
         FractionBox[
          RowBox[{
           InterpretationBox[
            StyleBox[
             OverscriptBox[
              InterpretationBox[
               StyleBox[GridBox[{
                  {"\[Sigma]", 
                   StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                    },
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                    FontSize->Rational[39, 4]]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
               
               Editable->False], ""],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Kh[
             xAct`xTensor`LI[0], 
             xAct`xTensor`LI[
             0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], " ", 
           RowBox[{"(", 
            InterpretationBox[
             StyleBox[
              RowBox[{
               OverscriptBox["\[Null]", 
                StyleBox[
                 RowBox[{"(", "1", ")"}],
                 FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
               OverscriptBox[
                InterpretationBox[
                 StyleBox["\[Psi]",
                  ShowAutoStyles->False,
                  AutoSpacing->False],
                 $CellContext`\[Psi]h[],
                 Editable->False], ""]}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[
              xAct`xTensor`LI[1], 
              xAct`xTensor`LI[0]],
             Editable->False], ")"}]}], 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[ScriptCapitalH]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Hh[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False]]}], ")"}]}]}]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output"]
}, Open  ]],

Cell["\<\
Or we can check a general transformation. For this we can even use a function \
which does everything in a simple manner for metric and matter fields \
perturbations:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplitFieldsAndGaugeChange", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], ",", "g", ",", "dg", ",", " ", "u", 
   ",", "du", ",", "h", ",", "order"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Xi]h", "[", 
    RowBox[{
     RowBox[{"LI", "[", "xAct`xPand`Private`ord$207139", "]"}], ",", 
     "\[Omega]$207140"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`\[Xi]h[
    xAct`xTensor`LI[
    xAct`xPand`Private`ord$207139], $CellContext`\[Omega]$207140], ". ", ""],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    StyleBox["\[Epsilon]",
     FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]g", 
         StyleBox[GridBox[{
            {"1", " ", " "},
            {" ", "\[Alpha]", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`dg[
      xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "1.199006`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", xAct`xPand`\[Epsilon] $CellContext`dg[
     xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]] 
   xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^2, " +... was performed in ", 1.199006, 
   " seconds."],
  Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   StyleBox["\[Epsilon]",
    FontColor->RGBColor[0.3, 0.8, 0.8]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Alpha]", "\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Eth[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"L", 
                StyleBox[GridBox[{
                   {"\[Gamma]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lvh[$CellContext`\[Gamma]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Lvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"L", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lvh[-$CellContext`\[Beta]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Lvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Beta]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"B", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bvh[-$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Bvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"L", 
                StyleBox[GridBox[{
                   {"\[Gamma]"},
                   {" "}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lvh[$CellContext`\[Gamma]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Lvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0], $CellContext`\[Gamma]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"L", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lvh[-$CellContext`\[Alpha]],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Lvh[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
        Editable->False], ")"}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["T",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Th[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Th[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Beta]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["T",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Th[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Th[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["T",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Th[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Th[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["T",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Th[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Th[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[1]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Phi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Phi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Phi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["h", "-"], 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["\[Psi]",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`\[Psi]h[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Psi]h[
         xAct`xTensor`LI[1], 
         xAct`xTensor`LI[0]],
        Editable->False], ")"}]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], "2"], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["\[ScriptCapitalH]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Hh[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Hh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False]], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Evh[-$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Evh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Beta]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["L",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lsh[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Lsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"L", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lvh[-$CellContext`\[Beta]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Lvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Beta]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["T",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Th[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Th[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["B",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Bsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Bsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"E", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Evh[-$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Evh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha]]],
        Editable->False], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["L",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lsh[],
            Editable->False], "\[Prime]"]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Lsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"L", 
                StyleBox[GridBox[{
                   {" "},
                   {"\[Alpha]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lvh[-$CellContext`\[Alpha]],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Lvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["T",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Th[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`Th[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["E",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Esh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Esh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Beta]"], 
          SubscriptBox[
           OverscriptBox["D", "_"], "\[Alpha]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["L",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[-$CellContext`\[Beta]][
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Lsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Beta]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Alpha]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Gamma]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["L",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Gamma]][
         $CellContext`Lsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["a",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], "2"], " ", 
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox[GridBox[{
             {"\[Sigma]", 
              StyleBox[GridBox[{
                 {" ", " "},
                 {"\[Alpha]", "\[Gamma]"}
                },
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
               FontSize->Rational[39, 4]]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Center}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           OverscriptBox["n", "-"], 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`n[-$CellContext`\[Beta]],
       Editable->False], " ", 
      RowBox[{"(", 
       InterpretationBox[
        StyleBox[
         RowBox[{
          SuperscriptBox[
           OverscriptBox["D", "_"], "\[Gamma]"], 
          OverscriptBox["\[Null]", 
           StyleBox[
            RowBox[{"(", "1", ")"}],
            FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
          OverscriptBox[
           InterpretationBox[
            StyleBox["L",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Lsh[],
            Editable->False], ""]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`cd[$CellContext`\[Gamma]][
         $CellContext`Lsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]],
        Editable->False], ")"}]}]}], ")"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExtractComponents", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ExtractOrder", "[", 
     RowBox[{"%", ",", "1"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       RowBox[{"ah", "[", "]"}], "^", "2"}]}], ")"}]}], ",", "h"}], 
  "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {"", "n", "h"},
    {"n", 
     RowBox[{
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["T",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Th[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Th[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], "+", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["T",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Th[],
           Editable->False], "\[Prime]"]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Th[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[1]],
       Editable->False], "+", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[Phi]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`\[Phi]h[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`\[Phi]h[
        xAct`xTensor`LI[1], 
        xAct`xTensor`LI[0]],
       Editable->False]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[-$CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Beta]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"L", 
                 StyleBox[GridBox[{
                    {"\[Gamma]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lvh[$CellContext`\[Gamma]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Lvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Gamma]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"L", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lvh[-$CellContext`\[Beta]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Lvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Beta]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["L",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lsh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`Lsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["T",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Th[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`Th[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Beta]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Gamma]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["L",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Gamma]][
          $CellContext`Lsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}]}]},
    {"h", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"B", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bvh[-$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Bvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"L", 
                 StyleBox[GridBox[{
                    {"\[Gamma]"},
                    {" "}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lvh[$CellContext`\[Gamma]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Lvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], $CellContext`\[Gamma]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"L", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lvh[-$CellContext`\[Alpha]],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Lvh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[1], -$CellContext`\[Alpha]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["B",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Bsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Bsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["L",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lsh[],
             Editable->False], "\[Prime]"]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Lsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[1]]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["T",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Th[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Th[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Gamma]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SuperscriptBox[
            OverscriptBox["D", "_"], "\[Gamma]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["L",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lsh[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[$CellContext`\[Gamma]][
          $CellContext`Lsh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]]],
         Editable->False], ")"}]}]}], 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" ", " "},
                    {"\[Alpha]", "\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Eth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Eth[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["T",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Th[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Th[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox[GridBox[{
              {"\[Sigma]", 
               StyleBox[GridBox[{
                  {" ", " "},
                  {"\[Alpha]", "\[Beta]"}
                 },
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                FontSize->Rational[39, 4]]}
             },
             
             GridBoxAlignment->{
              "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
               "Rows" -> {{Center}}, "RowsIndexed" -> {}},
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.27999999999999997`], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
               "Rows" -> {
                 Offset[0.2], {
                  Offset[0.4]}, 
                 Offset[0.2]}, "RowsIndexed" -> {}}],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["T",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Th[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Th[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], "+", 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["h", "-"], 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
        Editable->False], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox["\[Psi]",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`\[Psi]h[],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Psi]h[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]],
         Editable->False], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox[GridBox[{
               {"\[Sigma]", 
                StyleBox[GridBox[{
                   {" ", " "},
                   {"\[Alpha]", "\[Beta]"}
                  },
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                 FontSize->Rational[39, 4]]}
              },
              
              GridBoxAlignment->{
               "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Center}}, "RowsIndexed" -> {}},
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.27999999999999997`], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                "Rows" -> {
                  Offset[0.2], {
                   Offset[0.4]}, 
                  Offset[0.2]}, "RowsIndexed" -> {}}],
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Kh[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
         Editable->False], " ", 
        RowBox[{"(", 
         InterpretationBox[
          StyleBox[
           RowBox[{
            OverscriptBox["\[Null]", 
             StyleBox[
              RowBox[{"(", "1", ")"}],
              FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
            OverscriptBox[
             InterpretationBox[
              StyleBox["\[Psi]",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`\[Psi]h[],
              Editable->False], ""]}],
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Psi]h[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0]],
          Editable->False], ")"}]}], 
       InterpretationBox[
        StyleBox[
         OverscriptBox[
          InterpretationBox[
           StyleBox["\[ScriptCapitalH]",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Hh[],
           Editable->False], ""],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Hh[
         xAct`xTensor`LI[0], 
         xAct`xTensor`LI[0]],
        Editable->False]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[-$CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Evh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`\[Beta]]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Alpha]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"L", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Beta]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lvh[-$CellContext`\[Beta]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Alpha]][
          $CellContext`Lvh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`\[Beta]]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"E", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Evh[-$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`Evh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`\[Alpha]]],
         Editable->False], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        InterpretationBox[
         StyleBox[
          RowBox[{
           SubscriptBox[
            OverscriptBox["D", "_"], "\[Beta]"], 
           OverscriptBox["\[Null]", 
            StyleBox[
             RowBox[{"(", "1", ")"}],
             FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
           OverscriptBox[
            InterpretationBox[
             StyleBox[GridBox[{
                {"L", 
                 StyleBox[GridBox[{
                    {" "},
                    {"\[Alpha]"}
                   },
                   GridBoxSpacings->{"Columns" -> {
                    Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                    Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
                  FontSize->Rational[39, 4]]}
               },
               
               GridBoxAlignment->{
                "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Center}}, "RowsIndexed" -> {}},
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}],
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Lvh[-$CellContext`\[Alpha]],
             Editable->False], ""]}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`cd[-$CellContext`\[Beta]][
          $CellContext`Lvh[
           xAct`xTensor`LI[1], 
           xAct`xTensor`LI[0], -$CellContext`\[Alpha]]],
         Editable->False], ")"}]}], "-", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "\[Beta]"], 
         SubscriptBox[
          OverscriptBox["D", "_"], "\[Alpha]"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["E",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Esh[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`\[Beta]][
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Esh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False], "-", 
      InterpretationBox[
       StyleBox[
        RowBox[{
         SubscriptBox[
          OverscriptBox["D", "_"], "\[Beta]"], 
         SubscriptBox[
          OverscriptBox["D", "_"], "\[Alpha]"], 
         OverscriptBox["\[Null]", 
          StyleBox[
           RowBox[{"(", "1", ")"}],
           FontColor->RGBColor[0.85, 0, 0]]], "\[NegativeThinSpace]", 
         OverscriptBox[
          InterpretationBox[
           StyleBox["L",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Lsh[],
           Editable->False], ""]}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`cd[-$CellContext`\[Beta]][
        $CellContext`cd[-$CellContext`\[Alpha]][
         $CellContext`Lsh[
          xAct`xTensor`LI[1], 
          xAct`xTensor`LI[0]]]],
       Editable->False]}]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "xAct`xPand`*"}]], "Input"],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["xAct`xPand`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["xAct`xPand`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["a",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"a", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["ExtractOrder",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ExtractOrder", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["ToBianchiType",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ToBianchiType", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[CurlyPhi]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"\[CurlyPhi]", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["av",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"av", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["H",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"H", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["ToConformalTime",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ToConformalTime", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[Psi]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"\[Psi]", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["a$",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"a$", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["IndicesDown",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"IndicesDown", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["ToConstantsOfStructure",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "ToConstantsOfStructure", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$CacheRules",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"$CacheRules", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["BackgroundFieldMethod",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "BackgroundFieldMethod", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["IndicesUp",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"IndicesUp", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["ToCosmicTime",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ToCosmicTime", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$CommutecdRules",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"$CommutecdRules", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["Bs",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Bs", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["Ls",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Ls", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["ToMetric",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ToMetric", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$ConformalTime",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"$ConformalTime", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["Bv",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Bv", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["Lv",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Lv", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["ToxPand",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ToxPand", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$FirstOrderTensorPerturbations",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "$FirstOrderTensorPerturbations", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["Conformal",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"Conformal", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["nt",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"nt", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["ToxPandFromRules",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ToxPandFromRules", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$FirstOrderVectorPerturbations",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "$FirstOrderVectorPerturbations", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["ConformalWeight",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ConformalWeight", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["P",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"P", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["V0",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"V0", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$ListFieldsBackgroundAndPerturbed",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "$ListFieldsBackgroundAndPerturbed", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["Connection",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"Connection", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["RulesSplitCovDsOfTensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "RulesSplitCovDsOfTensor", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["VisualizeTensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"VisualizeTensor", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$ListFieldsBackgroundOnly",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "$ListFieldsBackgroundOnly", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["CS",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"CS", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["RulesVelocitySpatial",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "RulesVelocitySpatial", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["Vs",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Vs", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$ListFieldsPerturbedOnly",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "$ListFieldsPerturbedOnly", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["DefConformalMetric",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"DefConformalMetric", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SetSlicing",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"SetSlicing", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["Vspat",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Vspat", "xAct`xPand`"}},
          
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$ListOfGauges",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"$ListOfGauges", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["DefMatterFields",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"DefMatterFields", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SpaceTimesOfDefinition",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "SpaceTimesOfDefinition", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["Vv",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Vv", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$ListOfSpaceTypes",
          BaseStyle->"InformationLink",
          ButtonData:>{
           "Info1513761239979-1327514", {"$ListOfSpaceTypes", "xAct`xPand`"}},
          
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["DefMetricFields",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"DefMetricFields", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SpaceType",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"SpaceType", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["xPand",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"xPand", "xAct`xPand`"}},
          
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$MyRules",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"$MyRules", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["DefProjectedTensor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"DefProjectedTensor", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SplitFieldsAndGaugeChange",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "SplitFieldsAndGaugeChange", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[ScriptK]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"\[ScriptK]", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$OpenConstantsOfStructure",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "$OpenConstantsOfStructure", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["DefProjectedTensorProperties",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "DefProjectedTensorProperties", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SplitGaugeChange",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"SplitGaugeChange", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[ScriptCapitalN]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"\[ScriptCapitalN]", "xAct`xPand`"}},
          
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$SortCovDAutomatic",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"$SortCovDAutomatic", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["Disclaimer",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"Disclaimer", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SplitMatter",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"SplitMatter", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[ScriptCapitalN]0",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"\[ScriptCapitalN]0", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$Version",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"$Version", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["d\[ScriptCapitalN]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"d\[ScriptCapitalN]", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SplitMetric",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"SplitMetric", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[ScriptCapitalN]i",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"\[ScriptCapitalN]i", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$xPertVersionExpected",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "$xPertVersionExpected", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["Es",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Es", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SplitNormalVector",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"SplitNormalVector", "xAct`xPand`"}},
          
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[Epsilon]",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"\[Epsilon]", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["$xTensorVersionExpected",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {
            "$xTensorVersionExpected", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"]},
        {
         ButtonBox["Et",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Et", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["SplitPerturbations",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"SplitPerturbations", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[Xi]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"\[Xi]", "xAct`xPand`"}},
          
          ButtonNote->"xAct`xPand`"], ""},
        {
         ButtonBox["Ev",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"Ev", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["T",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"T", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[Rho]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"\[Rho]", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], ""},
        {
         ButtonBox["ExtractComponents",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"ExtractComponents", "xAct`xPand`"}},
          
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["TensorProperties",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info1513761239979-1327514", {"TensorProperties", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], 
         ButtonBox["\[Phi]",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info1513761239979-1327514", {"\[Phi]", "xAct`xPand`"}},
          ButtonNote->"xAct`xPand`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.2375]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Technical extension of xAct", "Subsubsection"],

Cell["\<\
We have also stopped the induced from opening the Scalars. So if a product is \
projected but not each factor of the product, then
the induced decomposition is used on each factor, and we avoid infinite \
recursion by blocking the derivative on the scalars. This is a technical \
detail\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DefTensor", "[", 
  RowBox[{
   RowBox[{"Test2", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], ",", "M", ",", 
   RowBox[{"OrthogonalTo", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "[", "\[Alpha]", "]"}], ",", 
      RowBox[{"n", "[", "\[Beta]", "]"}]}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cd", "[", "\[Mu]", "]"}], "[", 
   RowBox[{
    RowBox[{"u", "[", "\[Alpha]", "]"}], 
    RowBox[{"u", "[", 
     RowBox[{"-", "\[Alpha]"}], "]"}]}], "]"}], "//", 
  "ToCanonical"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cd", "[", "\[Mu]", "]"}], "[", 
   RowBox[{
    RowBox[{"Test2", "[", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], ",", 
      RowBox[{"-", "\[Beta]"}]}], "]"}], 
    RowBox[{"u", "[", "\[Alpha]", "]"}], 
    RowBox[{"u", "[", "\[Beta]", "]"}]}], "]"}], "//", 
  "ToCanonical"}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Test2", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`Test2[-$CellContext`\[Alpha], -$CellContext`\[Beta]], ". ", 
   ""],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      UnderscriptBox["P", 
       OverscriptBox["h", "-"]], "[", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"u", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`u[$CellContext`\[Alpha]],
       Editable->False], "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Projectorh[
     $CellContext`u[$CellContext`\[Alpha]]],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox[
        OverscriptBox["D", "_"], "\[Mu]"], 
       UnderscriptBox["P", 
        OverscriptBox["h", "-"]], "[", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"u", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`u[-$CellContext`\[Alpha]],
        Editable->False], "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[$CellContext`\[Mu]][
      $CellContext`Projectorh[
       $CellContext`u[-$CellContext`\[Alpha]]]],
     Editable->False], ")"}]}], "-", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      StyleBox["(",
       FontColor->RGBColor[1, 0, 0]], 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"u", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`u[-$CellContext`\[Alpha]],
        Editable->False]}], 
      StyleBox[")",
       FontColor->RGBColor[1, 0, 0]]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    xAct`xTensor`Scalar[$CellContext`n[$CellContext`\[Alpha]] \
$CellContext`u[-$CellContext`\[Alpha]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      SuperscriptBox[
       OverscriptBox["D", "_"], "\[Mu]"], 
      StyleBox["(",
       FontColor->RGBColor[1, 0, 0]], 
      RowBox[{
       InterpretationBox[
        StyleBox[GridBox[{
           {
            OverscriptBox["n", "-"], 
            StyleBox[GridBox[{
               {"\[Alpha]"},
               {" "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`n[$CellContext`\[Alpha]],
        Editable->False], " ", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"u", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`u[-$CellContext`\[Alpha]],
        Editable->False]}], 
      StyleBox[")",
       FontColor->RGBColor[1, 0, 0]]}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`cd[$CellContext`\[Mu]][
     xAct`xTensor`Scalar[$CellContext`n[$CellContext`\[Alpha]] \
$CellContext`u[-$CellContext`\[Alpha]]]],
    Editable->False]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      UnderscriptBox["P", 
       OverscriptBox["h", "-"]], "[", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"u", 
           StyleBox[GridBox[{
              {" "},
              {"\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`u[-$CellContext`\[Beta]],
       Editable->False], "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Projectorh[
     $CellContext`u[-$CellContext`\[Beta]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Test2", 
        StyleBox[GridBox[{
           {"\[Alpha]", "\[Beta]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Test2[$CellContext`\[Alpha], $CellContext`\[Beta]],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox[
        OverscriptBox["D", "_"], "\[Mu]"], 
       UnderscriptBox["P", 
        OverscriptBox["h", "-"]], "[", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"u", 
            StyleBox[GridBox[{
               {" "},
               {"\[Alpha]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`u[-$CellContext`\[Alpha]],
        Editable->False], "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[$CellContext`\[Mu]][
      $CellContext`Projectorh[
       $CellContext`u[-$CellContext`\[Alpha]]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      UnderscriptBox["P", 
       OverscriptBox["h", "-"]], "[", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"u", 
           StyleBox[GridBox[{
              {" "},
              {"\[Alpha]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`u[-$CellContext`\[Alpha]],
       Editable->False], "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Projectorh[
     $CellContext`u[-$CellContext`\[Alpha]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"Test2", 
        StyleBox[GridBox[{
           {"\[Alpha]", "\[Beta]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Test2[$CellContext`\[Alpha], $CellContext`\[Beta]],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox[
        OverscriptBox["D", "_"], "\[Mu]"], 
       UnderscriptBox["P", 
        OverscriptBox["h", "-"]], "[", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"u", 
            StyleBox[GridBox[{
               {" "},
               {"\[Beta]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`u[-$CellContext`\[Beta]],
        Editable->False], "]"}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[$CellContext`\[Mu]][
      $CellContext`Projectorh[
       $CellContext`u[-$CellContext`\[Beta]]]],
     Editable->False], ")"}]}], "+", 
  RowBox[{
   InterpretationBox[
    StyleBox[
     RowBox[{
      UnderscriptBox["P", 
       OverscriptBox["h", "-"]], "[", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"u", 
           StyleBox[GridBox[{
              {"\[Alpha]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`u[$CellContext`\[Alpha]],
       Editable->False], "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Projectorh[
     $CellContext`u[$CellContext`\[Alpha]]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     RowBox[{
      UnderscriptBox["P", 
       OverscriptBox["h", "-"]], "[", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"u", 
           StyleBox[GridBox[{
              {"\[Beta]"},
              {" "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`u[$CellContext`\[Beta]],
       Editable->False], "]"}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Projectorh[
     $CellContext`u[$CellContext`\[Beta]]],
    Editable->False], " ", 
   RowBox[{"(", 
    InterpretationBox[
     StyleBox[
      RowBox[{
       SuperscriptBox[
        OverscriptBox["D", "_"], "\[Mu]"], GridBox[{
         {"Test2", 
          StyleBox[GridBox[{
             {" ", " "},
             {"\[Alpha]", "\[Beta]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}]}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`cd[$CellContext`\[Mu]][
      $CellContext`Test2[-$CellContext`\[Alpha], -$CellContext`\[Beta]]],
     Editable->False], ")"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other Stuff", "Subsection"],

Cell["Weyl Tensor", "Text"],

Cell["Electric part", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MyxPand", "[", 
   RowBox[{
    RowBox[{"WeylCD", "[", 
     RowBox[{
      RowBox[{"-", "\[Alpha]"}], ",", " ", 
      RowBox[{"-", "\[Nu]"}], ",", " ", 
      RowBox[{"-", "\[Beta]"}], ",", " ", 
      RowBox[{"-", "\[Mu]"}]}], "]"}], ",", " ", "\"\<AnyGauge\>\"", ",", " ",
     "0"}], "]"}], " "}], "\n", 
 RowBox[{
  RowBox[{"ExtractComponents", "[", 
   RowBox[{"%", ",", " ", "h", ",", " ", 
    RowBox[{"{", 
     RowBox[{"h", ",", " ", "n", ",", " ", "h", ",", " ", "n"}], "}"}]}], 
   "]"}], " "}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["g", "_"], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"R", "[", 
          OverscriptBox["\[Del]", "_"], "]"}], 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Alpha]", "\[Beta]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`RicciCD[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
     Editable->False], " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       RowBox[{
        StyleBox["(",
         FontColor->RGBColor[1, 0, 0]], 
        InterpretationBox[
         StyleBox[
          OverscriptBox[
           InterpretationBox[
            StyleBox["a",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`ah[],
            Editable->False], ""],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]],
         Editable->False], 
        StyleBox[")",
         FontColor->RGBColor[1, 0, 0]]}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      xAct`xTensor`Scalar[
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]]],
      Editable->False], "2"]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "13.986325`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", 
   Rational[-1, 
     2] $CellContext`g[-$CellContext`\[Mu], -$CellContext`\[Nu]] \
$CellContext`RicciCD[-$CellContext`\[Alpha], -$CellContext`\[Beta]] 
   xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^2, " +... was performed in ", 13.986325, 
   " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Nu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Nu]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Nu]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Nu]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Nu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Nu]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Nu]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Nu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Nu]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Nu]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Mu]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Beta]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Nu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Nu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Mu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Mu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Nu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Nu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Mu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Nu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Nu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Beta]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Mu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Mu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Mu]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Beta]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Lambda]", "\[Sigma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Sigma]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Lambda]", "\[Sigma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Sigma]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Lambda]", "\[Sigma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Sigma]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Lambda]", "\[Sigma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Sigma]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Lambda]", "\[Sigma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Sigma]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Lambda]", "\[Sigma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Sigma]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Lambda]", "\[Sigma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Sigma]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Lambda]", "\[Sigma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Sigma]"},
           {"\[Gamma]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "12"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", "\[Lambda]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "12"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", "\[Lambda]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", "\[Lambda]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", "\[Lambda]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", "\[Lambda]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", "\[Lambda]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["5", "12"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Lambda]", " "},
           {" ", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["5", "12"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Lambda]", " "},
           {" ", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Lambda]", " "},
           {" ", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Lambda]", " "},
           {" ", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Lambda]", " "},
           {" ", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Lambda]", " "},
           {" ", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Beta], -$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Nu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Nu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Nu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Nu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Nu]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Beta]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Nu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Beta]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Mu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Beta]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Beta], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Beta], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Mu]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Beta]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Beta]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", "\[Gamma]"},
              {"\[Alpha]", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Beta]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Alpha]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Alpha]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["n", "-"], 
        StyleBox[GridBox[{
           {" "},
           {"\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`n[-$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Nu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
    Editable->False]}]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "3"]}], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Gamma]", "\[Lambda]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {"\[Gamma]", "\[Lambda]"},
              {" ", " "}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
       Editable->False], ""],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[
     OverscriptBox[
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Sigma]", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`Kh[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
       Editable->False], "\[Prime]"],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`Kh[
     xAct`xTensor`LI[0], 
     xAct`xTensor`LI[1], -$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Mu]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Lambda]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", "\[Lambda]"},
           {" ", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        OverscriptBox["h", "-"], 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Alpha]", "\[Mu]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`h[-$CellContext`\[Alpha], -$CellContext`\[Mu]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Gamma]", " "},
           {" ", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {"\[Lambda]", " "},
           {" ", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
    Editable->False]}], "-", 
  RowBox[{
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Gamma]"},
           {"\[Alpha]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Alpha], $CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Mu]", "\[Gamma]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
    Editable->False]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"A", 
        StyleBox[GridBox[{
           {"\[Gamma]"},
           {" "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`avh[$CellContext`\[Gamma]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {
        RowBox[{"\[Epsilon]", 
         OverscriptBox["h", "-"]}], 
        StyleBox[GridBox[{
           {" ", " ", " "},
           {"\[Alpha]", "\[Gamma]", "\[Lambda]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`epsilonh[-$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"N", 
        StyleBox[GridBox[{
           {" ", "\[Lambda]"},
           {"\[Mu]", " "}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
    Editable->False]}]}]], "Output"]
}, Open  ]],

Cell["Spatial components", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"MyxPand", "[", 
  RowBox[{
   RowBox[{"WeylCD", "[", 
    RowBox[{"\[Alpha]", ",", " ", "\[Beta]", ",", " ", 
     RowBox[{"-", "\[Mu]"}], ",", " ", 
     RowBox[{"-", "\[Nu]"}]}], "]"}], ",", " ", "\"\<AnyGauge\>\"", ",", " ", 
   "0"}], "]"}], "\n", 
 RowBox[{"exprCspat", " ", "=", " ", 
  RowBox[{"ExtractComponents", "[", 
   RowBox[{"%", ",", " ", "h", ",", " ", 
    RowBox[{"{", 
     RowBox[{"h", ",", " ", "h", ",", " ", "h", ",", " ", "h"}], "}"}]}], 
   "]"}], " "}]}], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"\[Delta]", 
           StyleBox[GridBox[{
              {"\[Beta]", " "},
              {" ", "\[Nu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {
           RowBox[{"R", "[", 
            OverscriptBox["\[Del]", "_"], "]"}], 
           StyleBox[GridBox[{
              {"\[Alpha]", " "},
              {" ", "\[Mu]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`RicciCD[$CellContext`\[Alpha], -$CellContext`\[Mu]],
       Editable->False]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox[
         RowBox[{
          StyleBox["(",
           FontColor->RGBColor[1, 0, 0]], 
          InterpretationBox[
           StyleBox[
            OverscriptBox[
             InterpretationBox[
              StyleBox["a",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`ah[],
              Editable->False], ""],
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`ah[
            xAct`xTensor`LI[0], 
            xAct`xTensor`LI[0]],
           Editable->False], 
          StyleBox[")",
           FontColor->RGBColor[1, 0, 0]]}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        xAct`xTensor`Scalar[
         $CellContext`ah[
          xAct`xTensor`LI[0], 
          xAct`xTensor`LI[0]]],
        Editable->False], "2"]}]]}], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "11.906875`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "The Splitting of ", Rational[-1, 2] 
   xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]] \
$CellContext`RicciCD[$CellContext`\[Alpha], -$CellContext`\[Mu]] 
   xAct`xTensor`Scalar[
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]]]^(-2), " +... was performed in ", 11.906875, 
   " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Nu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Mu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Mu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Nu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Mu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Nu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Mu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Nu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Nu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Nu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Mu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Mu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Nu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Nu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Mu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Mu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Nu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Nu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Mu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Nu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Nu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]", " "},
            {" ", " ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], $CellContext`\[Beta], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Mu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Mu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Mu]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]", " "},
            {" ", " ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], $CellContext`\[Beta], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Lambda]", "\[Sigma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Sigma]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Lambda]", "\[Sigma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Sigma]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Mu]", "\[Lambda]", "\[Sigma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Mu], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Sigma]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {" ", " ", " "},
            {"\[Nu]", "\[Lambda]", "\[Sigma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[-$CellContext`\[Nu], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Sigma]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Lambda]", "\[Sigma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Sigma]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Lambda]", "\[Sigma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Sigma]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Lambda]", "\[Sigma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Sigma]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Lambda]", "\[Sigma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Lambda], \
-$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Sigma]"},
            {"\[Gamma]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"4", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]", " "},
            {" ", " ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], $CellContext`\[Beta], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Gamma]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Nu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]", " "},
            {" ", " ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], $CellContext`\[Beta], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Gamma]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {"\[Gamma]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", "\[Gamma]"},
               {"\[Mu]", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Gamma], \
-$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Lambda]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]]}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[Sigma]", 
             StyleBox[GridBox[{
                {"\[Alpha]", " "},
                {" ", "\[Nu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Nu]],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Kh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Nu]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[Sigma]", 
             StyleBox[GridBox[{
                {"\[Beta]", " "},
                {" ", "\[Mu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Mu]],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Kh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Mu]],
      Editable->False]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]]}], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Mu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Nu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Gamma]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Gamma], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Gamma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Gamma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Gamma]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Gamma], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Gamma], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{"5", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{"5", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]", " "},
            {" ", " ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], $CellContext`\[Beta], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Gamma]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]", " "},
            {" ", " ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], $CellContext`\[Beta], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Gamma]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplitPerturbations", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ah", "[", "]"}], "^", 
     RowBox[{"(", 
      RowBox[{"-", "2"}], ")"}]}], " ", 
    RowBox[{"Antisymmetrize", "[", 
     RowBox[{
      RowBox[{"Antisymmetrize", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"Kh", "[", 
           RowBox[{"\[Alpha]", ",", " ", 
            RowBox[{"-", "\[Mu]"}]}], "]"}], " ", 
          RowBox[{"Kh", "[", 
           RowBox[{"\[Beta]", ",", " ", 
            RowBox[{"-", "\[Nu]"}]}], "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"1", "/", "3"}], " ", 
          RowBox[{"h", "[", 
           RowBox[{"\[Alpha]", ",", " ", 
            RowBox[{"-", "\[Mu]"}]}], "]"}], " ", 
          RowBox[{"h", "[", 
           RowBox[{"\[Beta]", ",", " ", 
            RowBox[{"-", "\[Nu]"}]}], "]"}], " ", 
          RowBox[{"Kh", "[", 
           RowBox[{"\[Lambda]", ",", " ", "\[Sigma]"}], "]"}], " ", 
          RowBox[{"Kh", "[", 
           RowBox[{
            RowBox[{"-", "\[Lambda]"}], ",", " ", 
            RowBox[{"-", "\[Sigma]"}]}], "]"}]}], " ", "-", " ", 
         RowBox[{"2", " ", 
          RowBox[{"h", "[", 
           RowBox[{"\[Alpha]", ",", " ", 
            RowBox[{"-", "\[Gamma]"}]}], "]"}], " ", 
          RowBox[{"h", "[", 
           RowBox[{"\[Beta]", ",", " ", 
            RowBox[{"-", "\[Nu]"}]}], "]"}], " ", 
          RowBox[{"ToCanonical", "[", 
           RowBox[{
            RowBox[{"LieD", "[", 
             RowBox[{"n", "[", "\[Alpha]", "]"}], "]"}], "[", 
            RowBox[{
             RowBox[{"h", "[", 
              RowBox[{"\[Sigma]", ",", " ", "\[Gamma]"}], "]"}], " ", 
             RowBox[{"Kh", "[", 
              RowBox[{
               RowBox[{"-", "\[Sigma]"}], ",", " ", 
               RowBox[{"-", "\[Mu]"}]}], "]"}]}], "]"}], "]"}]}]}], ",", " ", 
        
        RowBox[{"{", 
         RowBox[{"\[Alpha]", ",", " ", "\[Beta]"}], "}"}]}], "]"}], ",", " ", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "\[Mu]"}], ",", " ", 
        RowBox[{"-", "\[Nu]"}]}], "}"}]}], "]"}]}], ",", " ", "h"}], 
  "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Splitting of \"\>", "\[InvisibleSpace]", 
   FractionBox["1", "2"], 
   "\[InvisibleSpace]", "\<\" +... was performed in \"\>", 
   "\[InvisibleSpace]", "1.821483`", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm["The Splitting of ", 
   Rational[1, 2], " +... was performed in ", 1.821483, " seconds."],
  Editable->False]], "Print"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[Sigma]", 
             StyleBox[GridBox[{
                {"\[Alpha]", " "},
                {" ", "\[Nu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Nu]],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Kh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Nu]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox[GridBox[{
            {"\[Sigma]", 
             StyleBox[GridBox[{
                {"\[Beta]", " "},
                {" ", "\[Mu]"}
               },
               GridBoxSpacings->{"Columns" -> {
                   Offset[0.], {
                    Offset[0.034999999999999996`]}, 
                   Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                    Offset[0.]}}, "RowsIndexed" -> {}}],
              FontSize->Rational[39, 4]]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Center}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.034999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Mu]],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Kh[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Mu]],
      Editable->False]}], 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]]}], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", " "},
               {" ", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], -$CellContext`\[Mu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", " "},
               {" ", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], -$CellContext`\[Nu]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Sigma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Lambda], -$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Lambda]", "\[Sigma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Lambda], $CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Lambda], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Sigma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Lambda], -$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Lambda]", "\[Sigma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Lambda], $CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Lambda], $CellContext`\[Sigma]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Lambda]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Lambda]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Lambda]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Lambda]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Lambda], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Lambda], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Lambda], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Lambda], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Sigma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Lambda], -$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Lambda]", "\[Sigma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Lambda], $CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Lambda], $CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Lambda], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Sigma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Lambda], -$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Lambda]", "\[Sigma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Lambda], $CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Lambda], $CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Nu]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Nu], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Nu], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Nu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Nu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Lambda], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Sigma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Lambda], -$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Lambda]", "\[Sigma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Lambda], $CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Lambda], $CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Beta]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Beta], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Lambda], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Alpha]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"\[Delta]", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     xAct`xTensor`delta[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Sigma]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Lambda], -$CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Lambda]", "\[Sigma]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Lambda], $CellContext`\[Sigma]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Lambda], $CellContext`\[Sigma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {"\[Alpha]", "\[Lambda]"},
               {" ", " "}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[$CellContext`\[Alpha], $CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], $CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Mu]", "\[Lambda]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Mu], -$CellContext`\[Lambda]],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0], -$CellContext`\[Mu], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], $CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox[GridBox[{
           {"\[Sigma]", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Lambda]", "\[Mu]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`Kh[-$CellContext`\[Lambda], -$CellContext`\[Mu]],
        Editable->False], "\[Prime]"],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Kh[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[1], -$CellContext`\[Lambda], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]"},
            {" "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[$CellContext`\[Beta]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["n", "-"], 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`n[-$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExtractComponents", "[", 
  RowBox[{
   RowBox[{"exprCspat", " ", "-", " ", "%"}], ",", " ", "h", ",", " ", 
   RowBox[{"{", 
    RowBox[{"h", ",", " ", "h", ",", " ", "h", ",", " ", "h"}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     InterpretationBox[
      StyleBox[GridBox[{
         {"A", 
          StyleBox[GridBox[{
             {" "},
             {"\[Nu]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`avh[-$CellContext`\[Nu]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {
          RowBox[{"\[Epsilon]", 
           OverscriptBox["h", "-"]}], 
          StyleBox[GridBox[{
             {"\[Beta]", " ", " "},
             {" ", "\[Mu]", "\[Gamma]"}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
      Editable->False], " ", 
     InterpretationBox[
      StyleBox[GridBox[{
         {"N", 
          StyleBox[GridBox[{
             {"\[Alpha]", "\[Gamma]"},
             {" ", " "}
            },
            GridBoxSpacings->{"Columns" -> {
                Offset[0.], {
                 Offset[0.034999999999999996`]}, 
                Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                 Offset[0.]}}, "RowsIndexed" -> {}}],
           FontSize->Rational[39, 4]]}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Center}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.034999999999999996`]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
      Editable->False]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        OverscriptBox[
         InterpretationBox[
          StyleBox["a",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`ah[],
          Editable->False], ""],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`ah[
        xAct`xTensor`LI[0], 
        xAct`xTensor`LI[0]],
       Editable->False], "2"]}]]}], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Beta]", " ", " "},
            {" ", "\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Beta], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Mu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", " ", " "},
            {" ", "\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], -$CellContext`\[Nu], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False]}], 
   SuperscriptBox[
    InterpretationBox[
     StyleBox[
      OverscriptBox[
       InterpretationBox[
        StyleBox["a",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`ah[],
        Editable->False], ""],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`ah[
      xAct`xTensor`LI[0], 
      xAct`xTensor`LI[0]],
     Editable->False], "2"]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Gamma]", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Gamma], -$CellContext`\[Lambda]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", "\[Lambda]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], $CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{"5", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{"5", " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Gamma]", " "},
            {" ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Gamma], -$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Lambda]", " "},
            {" ", "\[Lambda]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Lambda], -$CellContext`\[Lambda]],
     Editable->False]}], 
   RowBox[{"12", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Mu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Nu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Nu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]", " "},
            {" ", " ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], $CellContext`\[Beta], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Gamma]"},
            {"\[Mu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Mu], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "+", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Beta]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Beta], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Alpha], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {
         OverscriptBox["h", "-"], 
         StyleBox[GridBox[{
            {"\[Alpha]", " "},
            {" ", "\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`h[$CellContext`\[Alpha], -$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {"\[Beta]", "\[Gamma]"},
            {" ", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[$CellContext`\[Beta], $CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", " "},
            {"\[Nu]", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], -$CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"A", 
         StyleBox[GridBox[{
            {" "},
            {"\[Mu]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`avh[-$CellContext`\[Mu]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {
         RowBox[{"\[Epsilon]", 
          OverscriptBox["h", "-"]}], 
         StyleBox[GridBox[{
            {"\[Alpha]", "\[Beta]", " "},
            {" ", " ", "\[Gamma]"}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`epsilonh[$CellContext`\[Alpha], $CellContext`\[Beta], \
-$CellContext`\[Gamma]],
     Editable->False], " ", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"N", 
         StyleBox[GridBox[{
            {" ", "\[Gamma]"},
            {"\[Nu]", " "}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`nth[-$CellContext`\[Nu], $CellContext`\[Gamma]],
     Editable->False]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox[
       OverscriptBox[
        InterpretationBox[
         StyleBox["a",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`ah[],
         Editable->False], ""],
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`ah[
       xAct`xTensor`LI[0], 
       xAct`xTensor`LI[0]],
      Editable->False], "2"]}]]}]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1289, 1006},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
Visible->True,
DockedCells->{
  Cell[
   BoxData[
    TemplateBox[{
      ButtonBox[
      "\"\[Dagger]\"", ButtonFunction :> Exit[], Appearance -> Automatic, 
       Evaluator -> Automatic, Method -> "Preemptive"], 
      ButtonBox[
      "\"\[RightTriangle]\"", ButtonFunction :> FrontEnd`FrontEndExecute[
         FrontEnd`FrontEndToken["EvaluatorStart"]], Evaluator -> None, 
       Appearance -> Automatic, Method -> "Preemptive"], 
      ButtonBox[
      "\"\[RightTriangle]\[RightTriangle]\"", ButtonFunction :> 
       FrontEnd`FrontEndExecute[
         FrontEnd`FrontEndToken["EvaluateNotebook"]], Evaluator -> None, 
       Appearance -> Automatic, Method -> "Preemptive"], 
      ButtonBox["\"EvalInit\"", ButtonFunction :> FrontEnd`FrontEndExecute[
         FrontEnd`FrontEndToken["EvaluateInitialization"]], Evaluator -> None,
        Appearance -> Automatic, Method -> "Preemptive"], 
      ButtonBox[
      "\"Init\"", 
       ButtonFunction :> (Module[{Utility`Toolbar`cell = NotebookSelection[
             SelectedNotebook[]], Utility`Toolbar`isInit}, 
          Utility`Toolbar`isInit = ReplaceAll[InitializationCell, 
             Options[Utility`Toolbar`cell, InitializationCell]]; If[
            TrueQ[
             Or[
             Utility`Toolbar`isInit == True, Utility`Toolbar`isInit == On]], 
            SetOptions[Utility`Toolbar`cell, InitializationCell -> False], 
            SetOptions[Utility`Toolbar`cell, InitializationCell -> True]]]; 
        Null), Appearance -> Automatic, Evaluator -> Automatic, Method -> 
       "Preemptive"], 
      ButtonBox["\"DeInit\"", ButtonFunction :> SetOptions[
         NotebookSelection[
          SelectedNotebook[]], InitializationCell -> False], Appearance -> 
       Automatic, Evaluator -> Automatic, Method -> "Preemptive"], 
      ButtonBox["\"\[DeleteKey]\"", ButtonFunction :> FrontEnd`FrontEndExecute[
         FrontEnd`FrontEndToken["DeleteGeneratedCells"]], Evaluator -> None, 
       Appearance -> Automatic, Method -> "Preemptive"]}, "Row", 
     DisplayFunction -> (
      RowBox[{#, "\[InvisibleSpace]", #2, "\[InvisibleSpace]", #3, 
        "\[InvisibleSpace]", #4, "\[InvisibleSpace]", #5, 
        "\[InvisibleSpace]", #6, "\[InvisibleSpace]", #7}]& ), 
     InterpretationFunction -> (RowBox[{"Row", "[", 
        RowBox[{"{", 
          RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6, ",", #7}], 
          "}"}], "]"}]& )]], "DockedCell"]},
PrivateNotebookOptions->{"FileOutlineCache"->False},
ShowSelection->True,
TrackCellChangeTimes->False,
Magnification->1,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "PastelColor.nb", 
  CharacterEncoding -> "UTF-8"]
]

